!$DEFINE MSOFT	! Kommentar entfernen, wenn Microsoft-Compiler angewandt wird

	PROGRAM STOER22
	PARAMETER (Version=2.23)
*-----------------------------------------------------------------------
*		 Strfall-Programm in FORTRAN 77
*			** PC-Version **
*			     V2.23
*-----------------------------------------------------------------------
*			  * AUFGABE *
* Berechnung der Schadstoffkonzentration fr eine zeitabhngig
* emittierende Quelle (Punkt-, Linien-, Flchen- oder Volumenquelle)
* bei einer mittleren und den "ungnstigsten" Ausbreitungssituationen
* entsprechend der
*		   VDI-Richtlinie 3783 Blatt 1
*	"Ausbreitung luftfremder Stoffe in der Atmosphre
*	  Ausbreitung von strfallbedingten Freisetzungen
*		   - Sicherheitsanalyse -"
*
* Diese Version kann zustzlich schwere Gase nach VDI 3783 Blatt 2
* behandeln, d.h. es knnen untere Znddistanzen und Kopplungspunkte
* fr die Kopplung mit Blatt 1 berechnet werden.
*
* Die Eingabe von Emissionsverlufen erfolgt auch bei schweren Gasen
* analog zu Blatt 1, d.h. als Folge konstanter Emissionsabschnitte und
* nicht wie bei Blatt 2 als Folge von Sttzpunkten.
*-----------------------------------------------------------------------
*			* BEARBEITER *
* Dr. Rainer Rckle
* TV Sdwest e.V.
* Robert-Bunsen-Strae 1
* 79108 Freiburg
*-----------------------------------------------------------------------
*			* GESCHICHTE *
* V.00  1984-1987	Prof.Manier -Inst.f.Meteorologie, TH Darmstadt
*			Version in FORTRAN IV fr Grorechenanlage.
*			Programmname: SF.FOR
* V.00  07-Jul-87	Rckle -Inst.f.Meteorologie, TH Darmstadt
*			Umstellung FORTRAN 77 mit Optimierung und
*			Verbesserung der Ein- und Ausgabe.
*			Programmname: S_FALL.FOR  V.00-V.04
* V1.00 09-Aug-89	S_FALL V.05 => STOER V1.00
*			Erweiterungen und Fehlerkorrekturen
*			gegenber S_FALL V.04.
* V1.10 19-Jul-90	zustzlich Wahl eines Aufpunkts in y-Richtung.
*			Ausgabe der Variablen im Batchmodus nur, wenn
*			Werte gendert wurden.
* V2.00 30-Nov-90	Schwergasphase nach Blatt 2 angekoppelt.
*			Ein- und Ausgaberoutinen berarbeitet.
*			Fehler bei Maximalkonzentrationsberechnung
*			an mehreren Aufpunkten behoben.
* V2.10 16-Apr-91	Programm um untere Znddistanzberechnung 
*			erweitert.
* V2.11 14-Aug-91	mittl. Windgeschw. bleibt jetzt auch bei
*			Batchsteuerung erhalten.
* V2.12 24-Apr-92	LOG(0) abfangen
* V2.20 27-Okt-93	NBLANK statt LAEN, Umstellungen, mehr Kommentar
* V2.21 08-Dez-93	bei Angabe von Schwergasparametern Q in g/s,
*			wenn Quelle eine Ausdehnung hat und SGPHAS
*			keine Schwergaseffekte diagnostiziert, dann
*			Q=Q/(XQ*YQ*ZQ)
*			VERSATZ.DAT und ZNDIST.DAT mit 21 Gebieten
* V2.22 16-Dez-93	Datum bei LAHEY richtig
* V2.23 02-Feb-94	Prozetemperaturabfrage nicht mehr auf Siede-
*			punkttemperatur limitiert.
*-----------------------------------------------------------------------
*			* PROBLEME *
* o Lt sich in der Regel nicht ohne Quellcode-nderungen auf anderen
*   Rechnern einsetzen, da compilerspezifische und systemspezifische
*   Eigenheiten genutzt wurden (siehe Handbuch).
*
* o Die Konzentrationsberechnung erfolgt bestenfalls auf 0.5% genau,
*   d.h. nur die ersten 2 oder 3 Stellen einer Zahl sind signifikant.
*   Bei langen Emissionsabschnitten kann es deshalb zur Berechnung
*   falscher Eintrittszeiten des Maximums kommen. Eine Verbesserung
*   wird erzielt, wenn die mit "Cexa" gekennzeichneten Zeilen im Unter-
*   programm EMISSI durch Lschen von Cexa bernommen werden.
*   Die Rechenzeit verdoppelt sich dadurch aber annhernd.
*-----------------------------------------------------------------------
* Beschreibung der PARAMETER:
* (!wenn diese Parameter gendert werden, so hat dies gleichermaen in
* allen Unterprogrammen zu erfolgen!)
*	 Anzahl der Sttzstellen (zeitliche Auflsung)
* NEMI - fr Emissionsverlauf
* NIMI - fr Immissionsverlauf
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
* MAXGAS - maximale Anzahl von Stoffen fr Schwergasausbreitung
* MAXGEB - maximale Anzahl von Ausbreitungsgebieten
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)
*-----------------------------------------------------------------------
* Beschreibung der VARIABLEN:
* Typbezeichnungen:	R*4 - REAL*4
*			I*4 - INTEGER*4
*			L*4 - LOGICAL*4
*			CHAR- CHARACTERstring unterschiedlicher Lnge
*
* 1.) globale Variablen
*-----------------------------------------------------------------------
* COMMON //
*-----------------------------------------------------------------------
* I*4  IGAS	Gasart (1-schwer, 2-dichteneutral, 3-leicht)
* R*4  H	effektive Quellhhe
* R*4  HI	Inversionshhe
* R*4  DH	berhhung
* I*4  IU	Windgeschwindigkeitsindex (bei mittlerer Wetterlage=0,
* 		sonst gleich der mittleren Geschwindigkeit in m/s)
* R*4  TA	Reisezeit eines Einzelpuffs
* R*4  U	Windgeschwindigkeit in Anemometerhhe (10m)
* R*4  UU	Windgeschwindigkeit gemittelt ber die eff.Quellhhe
* R*4  UM0	Ausgangswindgeschwindigkeit festhalten
* R*4  SS	Konzentration am Aufpunkt XA,YA,ZA zur Zeit T
* R*4  T	Zeit nach Emissionsbeginn
* I*4  IK	Stabilittsparameter (1= stabil,2= indifferent,3= labil)
* R*4  TTD	Zeitintervall entsprechend der Auflsung der
*		Beaufschlagungszeit
* I*4  N4	Exponent der die zeitliche Auflsung in den einzelnen
* 		Emissionsabschnitten bestimmt
* R*4  Z0	Rauhigkeitslnge
* R*4  TU	Entfernung des Einzelpuffs vom Koordinatenursprung (Tau*u)
* I*4  NNN	maximale Anzahl der zeitlichen Auflsung der Immissions-
* 		konzentration
* R*4  SY	Streuung der Schadstoffkonzentration in der Horizontalen
* 		quer zur mittleren Windrichtung
* R*4  CCSUM	Summe der Konzentrationen eines Konzentrationsverlaufs
* L*4  INVRS	Rechnungen mit oder ohne Inversionseinflu
* L*4  LXQ,LYQ,	.TRUE. wenn Quellabmessung in die entsprechende Richtung
*      LZQ	mindestens 1m ist
*
*-----------------------------------------------------------------------
* COMMON /INPUT/
*-----------------------------------------------------------------------
* R*4  UM	Windgeschwindigkeit fr die mittlere Ausbreitungs-
*		situation
* R*4  HM	Hhe der Umgebungsbebauung
* R*4  HQ	Quellhhe
* R*4  XQ	Lnge der Quelle (x-Richtung)
* R*4  YQ	Breite der Quelle (y-Richtung)
* R*4  ZQ	Hhe der Quelle (z-Richtung)
* R*4  XA	Entfernung des Aufpunkts in x-Richtung vom Koordinatenursprung
* R*4  YA	Entfernung des Aufpunkts in y-Richtung vom Koordinatenursprung
* R*4  ZA	Entfernung des Aufpunkts in z-Richtung vom Koordinatenursprung
* R*4  T0	erste Sttzstelle fr den Immissionsverlauf
* R*4  DT	Zeitschritt in dem weitere Sttzstellen auf T0 folgen
* I*4  IAI	1=Ergebnisse in Datei abspeichern
* 		2=nicht abspeichern
* I*4  IZ0	Rauhigkeitsklasse
* I*4  NUE	1=berhhung bercksichtigen
* 		2=nicht bercksichtigen
* I*4  NTM	vorgegebene Anzahl der Sttzstellen fr die zeitliche
* 		Auflsung der Immissionskonzentrartion
* I*4  NZI	0= 1,2 und 3 berechnen
*		1= Dosis berechnen
* 		2= Maximalkonzentration berechnen
* 		3= Konzentrationsverlauf berechnen
* I*4  MW	0= mittl. Ausbreitungssituation und ungnstige
*		   Ausbreitungssit. berechnen
*		>0 nur vorgegebene Wetterlage mit Inversionseinflu
*		<0 nur vorgegebene Wetterlage ohne Inversionseinflu
* I*4  IW	1=Wrmeemission direkt angegeben
* 		2=Wrmeemission berechnen
* I*4  IQ	1=Bestimmung der berhhung mit Schadstoffdichte
* 		2=Bestimmung der berhhung mit Schadstofftemperatur
* I*4  IQA	Quellartparameter (Punkt,Linie,Flche,Volumen)
* I*4  JO	erweiterte Optionen gewnscht oder nicht (1=ja, 2=nein)
* I*4  JST	Kennung ob Immissionsverlauf vorgegeben wurde
*		=0 Berechnung der Sttzstellen aus Beaufschlagungszeiten
*		=1 Berechnung aus T0 und DT
*		=2 einzelne Zeiten explizit vorgegeben
* I*4  INFO	Informationslevel fr Bildschirmausgabe
*		0= nur Ergebnisse, 1= Rechengang+Erg., 2= 1 + Statuszeile
*
*-----------------------------------------------------------------------
* COMMON /DMKM/
*-----------------------------------------------------------------------
* R*4  HI0	Mindesthhe der Inversion
* R*4  HIXA	Hhe der Inversion am Aufpunkt
* R*4  UUXA	Transportgeschwindigkeit am Aufpunkt
* R*4  HXA	eff. Quellhhe am Aufpunkt
* L*4  Z9(3)	Hilfsvariable bei der Auswahl der ungnstigsten
*		Ausbreitungssituation
* R*4  CDMAX	max. Dosis wurde bestimmt bei folgenden Verhltnissen
* R*4  UDMAX	Transportgeschw.
* R*4  HDMAX	eff. Quellhhe
* I*4  KDMAX	Ausbreitungsklasse
* I*4  IDMAX	Geschw. in Anemometerhhe
* L*4  DINC	Flag, ob weitere Steigerung der Geschwindigkeit sinnvoll
*		ist
* R*4  CCMAX	Maximalkonz. wurde bestimmt bei folgenden Verhltnissen
* R*4  UCMAX	Transportgeschw.
* R*4  HCMAX	eff. Quellhhe
* I*4  KCMAX	Ausbreitungsklasse
* I*4  ICMAX	Geschw. in Anemometerhhe
* L*4  CINC	Flag, ob weitere Steigerung der Geschwindigkeit sinnvoll
*		ist
* R*4  TCMAX	Eintrittszeit des Maximums
*
*-----------------------------------------------------------------------
* COMMON /TEXT/		Texte
*-----------------------------------------------------------------------
* CHAR QUEART(4) Kennzeichnung der Art der Quelle
* CHAR QUEDIM(4) Dimension der Quellstrke fr die jeweilige Quellart
* CHAR DATEI	 Dateiname der Ergebnisdatei
* CHAR JANEIN(2) Ausgabetext: ' ja ' und 'nein'
* CHAR TITEL	 berschrift zur Kennzeichnung der Berechnung
* CHAR STRING	 eingelesene Zeile
* CHAR STNAME	 Stoffname
*
*-----------------------------------------------------------------------
* COMMON /CONST/	einige Konstanten
*-----------------------------------------------------------------------
* R*4  Z0I(5)	Rauhigkeitslngen in m fr die 5 Rauhigkeitsklassen (IZ0)
* R*4  PI	Pi=3.141
* R*4  W2PI	sqrt(2*Pi)
* R*4  DW2PI	1/sqrt(2*pi)
* R*4  DW2PI3	1/sqrt(2*pi)**3
* R*4  WPIH	sqrt(pi/2)
* R*4  W2	sqrt(2)
*
*-----------------------------------------------------------------------
* COMMON /EMVER/	Emissionsverlauf
*-----------------------------------------------------------------------
* I*4  NQ	Anzahl der Emissionsabschnitte konst. Emission
* R*4  TD(nemi)	Dauer der Emission fr Intervalle konstanter Emission
* R*4  S(nemi)	Konzentration fr die einzelnen Emissionsabschnitte
* R*4  Z1Z(nemi)>0 hchste Auflsung (XA/100) noch nicht erreicht
* 		=0 hchste Auflsung erreicht
* R*4  SU(nemi)	Konzentration fr die einzelnen Emissionsabschnitte
* R*4  TQ(nemi)	Sttzstellen fr die zeitliche Auflsung der Emission.
* 		Jeweils die Zeit nach Emissionsbeginn
* R*4  Q(nemi)	Quellstrke je nach Quellart in
* 		g/s	 - Punktquelle   (XQ<1 und  YQ<1 und  ZQ<1)
* 		g/m/s	 - Linienquelle  (XQ>1 oder YQ>1 oder ZQ>1)
* 		g/m**2/s - Flchenquelle (XQ<1 oder YQ<1 oder ZQ<1)
* 		g/m**3/s - Volumenquelle (XQ>1 und  YQ>1 und  ZQ>1)
* R*4  QH(nemi)	Wrmeemission fr die einzelnen Zeitintervalle konst.
*		Emission
* R*4  R(nemi)	Volumenstrom in m**3/s
* 		fr die einzelnen Zeitintervalle konst. Emission
* R*4  RO(nemi)	Dichte des Schadstoffes in kg/m**3 fr die einzelnen
* 		Zeitintervalle konst.Emission
* R*4  TT(nemi)	Schadstofftemperatur in Grad C fr die einzelnen
* 		Zeitintervalle konst. Emission
*
*-----------------------------------------------------------------------
* COMMON /IMVER/	Immissionsverlauf
*-----------------------------------------------------------------------
* R*4  CC(nimi)	Immissionskonzentration in mg/m**3
* R*4  TIME(nimi) Immissionssttzstellen - Zeitpunkte zu denen die
*		  Konzentration ausgegeben wird
* R*4  TS(nimi)	explizit vorgegebene Zeiten zu denen die Konz. bestimmt
*		werden soll
*
*-----------------------------------------------------------------------
* COMMON /SGAS/		Schwergasdaten
*-----------------------------------------------------------------------
* R*4  DXI(I,J)	Quellversatz in char. Lngeneinheiten
* R*4  DTI(I,J)	Zeitversatz in char. Zeiteinheiten
* R*4  DXC(I,J)	Quellversatz in char. Lngeneinheiten
* R*4  SIEDP	Siedepunkt
* R*4  RHONOR	Normdichte (Dichte bei 0 Grad C und 1013 hPa)
* R*4  UZG	untere Zndgrenze
* I*4  MGAS	Anzahl der bekannten Stoffe
* I*4  MGEB	Anzahl der bekannten Ausbreitungsgebiete
* I*4  NGAS	Stoffart
* I*4  NGEB	Ausbreitungsgebiet
* I*4  NFORM	Freisetzungsform (1-4)
* R*4  TPROZ	Prozetemperatur in Grad C. Default 15 Grad C
* R*4  QTOTAL	Gesamtmasse in g
* R*4  RLC(2)	Charakteristisches Lngenma in m
* R*4  UZD(2)	untere Znddistanzen  (1=mittlere, 2=maximale)
* R*4  UC	Charakteristische Geschwindigkeit in m/s
* R*4  CK	Konzentration am Kopplungspunkt in mg/m**3
* I*4  IFREI	Freisetzungsart: 1=spontan, 2=kontinuierlich
* I*4  IERR	wenn schweres Gas nicht als solches behandelt, dann
*		Kennung fr Ausschlukriterium in IERR
* I*4  NUR2	Nur Schwergasphase rechnen
* R*4  XK(2,2)	Quellversatz
* R*4  DTS(2)	Zeitversatz  (Dauer bis zur Kopplung)
*		1= mittlere, 2= ungnstigste Ausbreitungssituation
* R*4  XR(2)	1. Aufpunkt
*
*-----------------------------------------------------------------------
* 2.) lokale Variablen im Hauptprogramm 	STOER
*-----------------------------------------------------------------------
* L*4  BATCH	Interaktiv/Batch-Flag
* I*4  I	Laufindex
* I*4  ICNT	1=weitere Aufpunkte auswerten
* 		2=keine weiteren Aufpunkte
* I*4  IGO	Flag ob Ende der Eingabedatei erreicht
* I*4  IWB	1=weitere Berechnungen machen, 2=Ende
* I*4  NC	0=nur Aufpunkt gendert, >0=andere Werte gendert
* L*4  OPN33	Ausgabedatei (UNIT=33) geffnet oder nicht
* CHAR WAS	Platz fr ein Zeichen
*
* === Felder ===
*
* === aufgerufene Unterprogramme ===
* AUSWER
* CLS
* DISPI
* EMPAR
* FOPEN
* FRAME
* GET1I
* GET1R
* GETJN
* GOPAR         
* (LAEN (I*4) ersetzt durch NBLANK)
* PARAUS
* PAREIN        
* PARSET
* QGPAR                 
* SGPAR                 
* SGPHAS                
* SOPAR                 
* UEPAR         
* WAIT                  
* XOPAR         
* === verwendete FORTRAN-Units
*  * - Bildschirm bzw. Tastatur
* 11 - Eingabedatei  STOER.INI
* 33 - Ergebnisdatei (oder PRN)
* 77 - Eingabedatei  GASE.DAT
* 88 - Eingabedatei  VERSATZ.DAT
* 99 - Eingabedatei  ZNDIST.DAT
*-----------------------------------------------------------------------

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	COMMON /CONST/	Z0I(5),PI,W2PI,DW2PI,DW2PI3,WPIH,W2


	CHARACTER	WAS*1

	LOGICAL		BATCH,OPN33
	DATA		BATCH,OPN33/2*.FALSE./

* ICNT	=1	weitere Aufpunkte auswerten
	DATA ICNT	/1/
* IWB	=1	weitere Berechnungen
	DATA IWB	/1/
* NC	=-1	Initialisierung in PAREIN
	DATA NC		/-1/

*----------------------------------------------------------------------
* Default-Einstellung der Eingabeparameter
*----------------------------------------------------------------------
	CALL	PARSET
	UM0=UM

* KONSTANTEN (fr ehemaliges KONZ)
	PI=4.*ATAN(1.)
	W2PI=SQRT(2.*PI)
	DW2PI=1./W2PI
	DW2PI3=DW2PI**3
	WPIH=W2PI/2.
	W2=SQRT(2.)

*-----------------------------------------------------------------------
* wenn Batch-Datei vorhanden, dann einlesen und bei GO ausfhren
* sonst in den interaktiven Teil verzweigen
*----------------------------------------------------------------------
	OPEN (UNIT=11,FILE='STOER.INI',STATUS='OLD',ERR=100)
	PRINT 121
121	FORMAT(' PAREIN-I-Datei STOER.INI geffnet.')

122	CALL PAREIN (IGO,NC)
* wenn IGO=0, dann Ende erreicht
	IF (BATCH.AND.IGO.LT.0)		GOTO 1111

* Z0 besetzen
	Z0=Z0I(IZ0)
* Quellhhe ist mindestens Z0
	IF (HQ.LT.Z0)	HQ=Z0
* Immissionssttzstellen besetzen, wenn JST>0
	IF (JST.EQ.1)	THEN
		DO  5551  I=1,nimi
5551		TIME(I)=T0+(I-1)*DT
		NTM=nimi
		TTD=DT
		ELSE IF (JST.EQ.2) THEN
		DO  5552  I=1,NTM
5552		TIME(I)=TS(I)
		TTD=0.
		END IF
* wenn nur fr eine Zeit gerechnet werden soll
	IF (NTM.EQ.1)	TIME(1)=TS(1)

*- mit GO gestartet => BATCH-Job
	IF (IGO.EQ.1)	THEN
	  BATCH=.TRUE.
*--- Schwergasphase rechnen ---
	  IF (IGAS.EQ.1)	CALL SGPHAS (BATCH)

	  IF (IAI.EQ.1)	 THEN
* Ausgabe in Datei oder auf Drucker
		CALL FOPEN (DATEI,OPN33)
* Ausgabe der Eingabedaten, wenn nderungen vorgenommen wurden
		IF (NC.GT.0)	CALL PARAUS (Version)
		END IF

* Ausgabe des Aufpunkts
	  PRINT 28,		XA,YA,ZA
	  IF (IAI.EQ.1)	 THEN
		WRITE (33,28)	XA,YA,ZA
		IF (IGAS.EQ.1)	THEN
			XZ=XA-XK(1,IFREI)
			IF (XZ.LT.XR(1))	WRITE (33,95)
			END IF

		IF ((IGAS.GT.1.AND.XA.LT.100.) .OR. YA.NE.0.)
     1						WRITE (33,288)
		END IF

*----------------------------------------------------------------------
* Daten auswerten
*----------------------------------------------------------------------
	  CALL AUSWER
* etwas Platz lassen
	  PRINT 101
101	  FORMAT(/80('-'))
	  IF (IAI.EQ.1)	WRITE (33,'(//)')
	  GOTO 122
	END IF

	CLOSE (UNIT=11)
	IF (BATCH)	STOP '* BATCH_ENDE *'

* mittlere Windgeschwindigkeit festhalten
	UM0=UM

*----------------------------------------------------------------------
* DIALOG - Start
*----------------------------------------------------------------------
100	CALL DISPI (Version)

 20	CALL FRAME ('Initialisierung')
*- Titel abfragen
	PRINT 61, TITEL
 61	FORMAT(/' Titel: ',A/6X,'> '\)
	READ (*,1,END=114,ERR=100)	STRING
	IF (STRING(1:1).NE.' ')	TITEL=STRING(1:70)

*- Ergebnisse in einer Datei speichern ?
 10	PRINT 60, JANEIN(IAI)
 60	FORMAT(/' Eingangsparameter und Ergebnisse abspeichern ?',T50,
     1	A5,T65,'>'\)
	CALL	GETJN (IAI,*114)
	IF (IAI.EQ.1)	THEN
		PRINT 65, DATEI
 65	FORMAT(' Dateiname fr die Ergebnisse ? ',T35,A,T65,'>'\)
		READ (*,1,END=114,ERR=10)	STRING
		IF (NBLANK(STRING).GT.0)	DATEI=STRING(1:30)
		CALL FOPEN (DATEI,OPN33)
		END IF

*- neutrales, schweres oder leichtes Gas ?
166	PRINT 66,IGAS,'>'
 66	FORMAT(//' Welche Gasart wird freigesetzt:'//
     1	5X,'1 - schweres Gas mit Schwergasphase nach Blatt 2'/
     2	5X,'2 - dichteneutrales Gas'/
     3	5X,'3 - leichtes Gas, bei dem ein Auftrieb zu bercksichtigen'
     3	' ist'//
     4	' Gasart',T50,I5:T65,A1\)
	CALL	GET1I (IGAS,1,3,*114)

*=== Einlesen der Eingangsparameter ====================================

*- bei schwerem Gas die entsprechenden Parameter einlesen --------------
	IF (IGAS.EQ.1)	THEN
		CALL SGPAR
*--- Emissionsverlauf ---
		IQA=1
		LXQ=.FALSE.
		LYQ=.FALSE.
		LZQ=.FALSE.
		CALL EMPAR
*--- Standortparameter ---
		IF (NUR2.EQ.2)	CALL SOPAR
*--- Schwergasphase rechnen ---
		CALL SGPHAS (BATCH)
		IF (NUR2.EQ.1)	THEN
*- nix im Fernfeld, dann Ausgabe des Ergebnisses und weiter mit Abfrage
*  ob nderung
			IF (IAI.EQ.1)	CALL PARAUS (Version)
			GOTO 114
			END IF

*--- Am Kopplungspunkt bekannt:
* CK    - Konzentration
* TQ,Q  - Emissionsverlauf
* mittlere 	"ungnstigste" 		Ausbreitungssituation
* XK(1,IFREI) 	XK(2,IFREI) 		- Entfernung zur Quelle
* DTS(1)      	DTS(2)      		- Zeitversatz
* XR(1)       	XR(2)       		- erster Aufpunkt

		ELSE

*--- Standortparameter ---
		CALL SOPAR
*--- Quellgeometrie ---
		CALL QGPAR
*--- Emissionsverlauf ---
		CALL EMPAR

*--- berhhung bercksichtigen ---
		IF (IGAS.EQ.3)	CALL UEPAR

		END IF

*--- Steuerparameter und weitere Optionen ---
	CALL GOPAR
* Optionen anbieten falls gewnscht
	IF (JO.EQ.1)	CALL XOPAR

*=======================================================================
* Ausgabe der Eingangsgren
*=======================================================================
530	IF (IAI.EQ.1)	CALL PARAUS (Version)

*----------------------------------------------------------------------
* Aufpunktkoordinaten abfragen
*----------------------------------------------------------------------
540	CALL FRAME ('Aufpunktkoordinaten')

	IF (IGAS.EQ.1)	THEN
		PRINT 369,XK(1,IFREI),XR(1)+XK(1,IFREI),
     1			  XK(2,IFREI),XR(2)+XK(2,IFREI)
369	FORMAT (' Im Schwergasfall wird am Kopplungspunkt XK eine',
     1		' Punktquelle angenommen.'/
     2		' Liegt der gewnschte Aufpunkt XA zwischen XK und',
     2		' XR=5*XK, so wird fr'/
     3		' den Aufpunkt XR gerechnet und anschlieend auf den',
     3		' Aufpunkt XA inter-'/' poliert.'/
     4		T50,'XK',10X,'XR'/
     5		' mittlere Ausbreitungssituation',T42,2(F10.1,' m')/
     6		' ungnstigste Ausbreitungssituation',T42,2(F10.1,
     6		' m')/)

		END IF
		
	PRINT 233, 'X',XA
	CALL	GET1R (XA,1.,0.,*114)

	IF (IGAS.EQ.1)	THEN
* im Schwergasfall kein Versatz des Aufpunktes (YA und ZA) mglich,
* sofern vor dem 1. Aufpunkt
		XZ=XA-XK(1,IFREI)
* noch im Schwergasbereich ?
		IF (XZ.LT.0.)	THEN
		   IF (XA.LT.UZD(1))	THEN
			PRINT 97
			IF (IAI.EQ.1)   WRITE (33,97)
 97	FORMAT (' Der Aufpunkt liegt noch im Zndbereich!')
			PRINT 91
			ELSE
			IF (IAI.EQ.1)	WRITE (33,91)
 91	FORMAT(/' Der Aufpunkt liegt noch im Bereich mit ber 1% der',
     1		' Anfangskonzentration.')
			END IF
		   CALL WAIT
		   GOTO 540
		   END IF

		IF (XZ.LT.XR(1))	THEN
			PRINT 92
 92	FORMAT(/' Fr diesen Aufpunkt mssen die Konzentrationen',
     1		' interpoliert werden.'/
     2		' Die Interpolation kann nur fr Aufpunkte YA=0 und',
     3		' ZA=0 erfolgen.')
			YA=0.
			ZA=0.
			CALL WAIT
			GOTO 287
			END IF
		END IF

	PRINT 233, 'Y',YA
* YA darf auch negativ sein
	CALL	GET1R (YA,-9.E9,0.,*114)
	PRINT 233, 'Z',ZA
	CALL	GET1R (ZA,0.,0.,*114)

233	FORMAT(T16,A1,'A=',F7.1,' m',T35,'> '\)

* Aufpunktkoordinaten ausgeben
287	CALL	CLS
	PRINT 28, XA,YA,ZA
	IF (IAI.EQ.1)	THEN
		WRITE (33,28) XA,YA,ZA
 28	FORMAT(/' Aufpunktkoordinaten:',3X,'XA=',F6.0,' m ;  YA=',
     1	F6.0,' m ;  ZA=',F6.0,' m'/)

		IF (XZ.LT.XR(1))	WRITE (33,95)
 95	FORMAT (' Fr diesen Aufpunkt mssen die Konzentrationen',
     1		' interpoliert werden.')
		END IF

	IF ((IGAS.GT.1 .AND. XA.LT.100.) .OR. YA.NE.0.) THEN
		PRINT 288
		IF (IAI.EQ.1)	WRITE (33,288)
288	FORMAT (' !! Berechnungen fr Aufpunkte mit Quellentfernungen',
     1		' unter 100m'/
     2		' !! oder Aufpunkte neben der Fahnenachse (YA<>0)'/
     3		' !! entsprechen nicht der Richtlinie 3783 Blatt 1.')
		END IF

*----------------------------------------------------------------------
* Auswertung dieses Parametersatzes
*----------------------------------------------------------------------
	CALL AUSWER

* etwas Platz in der Datei lassen - neuer Fall dann abgesetzt
	IF (IAI.EQ.1)	WRITE (33,'(//)')
* da UM umgesetzt wurde, auf alten Wert zurcksetzen
	UM=UM0
*----------------------------------------------------------------------
* weitere Aufpunkte auswerten ?
*----------------------------------------------------------------------
	PRINT 113,	JANEIN(ICNT)
113	FORMAT(/' weitere Aufpunkte auswerten ?',T50,A5,T70,'>'\)
	CALL	GETJN (ICNT,*1111)
	IF (ICNT.EQ.1)	GOTO 540

*----------------------------------------------------------------------
* ? Ende der Berechnungen
*----------------------------------------------------------------------
114	PRINT 115,	JANEIN(IWB)
115	FORMAT(' sollen weitere Berechnungen gemacht werden ?',
     1	T50,A5,T70,'>'\)
	CALL	GETJN (IWB,*1111)
	IF (IWB.EQ.2)	GOTO 1111

*----------------------------------------------------------------------
* Abfrage was gendert werden soll:
*----------------------------------------------------------------------
	CALL FRAME ('Parameter ndern')
	PRINT 116
116	FORMAT( 20X,'G - anderes Gas'/
     1		20X,'Q - andere Quellparameter'/
     2		20X,'E - anderer Emissionsverlauf'/
     2		20X,'S - andere Standortparameter'/
     3		20X,'R - andere Steuerparameter'/
     4		20X,'O - andere Optionen'/
     2		20X,'A - mehrere Parameter ndern'//
     9	' Kennung: > '\)
	READ (*,1,END=1111) WAS
* Verzweigen
	I=INDEX('?gGqQeEsSrRoOaA',WAS)/2
	IF (I.EQ.0)	GOTO 114
* Gasart
	IF (I.EQ.1)	GOTO 166
* Quellgeometrie
	IF (I.EQ.2)	CALL QGPAR
* Emissionsverlauf
	IF (I.LE.3)	CALL EMPAR
* Standortparameter
	IF (I.EQ.4)	CALL SOPAR
* Steuerparameter
	IF (I.EQ.5)	THEN
		CALL GOPAR
		I=7-JO
		END IF
* Optionen
	IF (I.EQ.6)	CALL XOPAR
* mehrere Parameter ndern
	IF (I.EQ.7)	GOTO  20

	GOTO 530

*----------------------------------------------------------------------
* Ende des Programms
*----------------------------------------------------------------------
1111	IF (OPN33) CLOSE (UNIT=33)
*------------------- ENDE ----------------------------------------------
  1	FORMAT(A)
	END

	SUBROUTINE	PAREIN (IGO,NC)
*-----------------------------------------------------------------------
* Eingabeparameter aus der Datei STOER.INI lesen und auf Gltigkeit
* berprfen.
*-----------------------------------------------------------------------
* Kennung und Bedeutung
*  1 TI	Titel
*  2 DA	Ergebnisdateinamen
*
*  3 UM	Mittl. Geschwindigkeit
*  4 HM	Bebauungshhe
*  5 IZ	Rauhigkeitsklasse
*  6 HQ	Quellhhe
*  7 XQ	Quelldimensionen in x-,y- und z-Richtung
*  8 YQ
*  9 ZQ
* 10 NQ	Anzahl der Emissionsabschnitte
* 11 TQ	Zeit nach Emissionsbeginn
* 12 QS	Quellstrke
* 13 QH	Wrmeemission
* 14 VS	Volumenstrom
* 15 TT	Schadstofftemperatur
* 16 RO	Schadstoffdichte
* 17 NS	Anzahl der Sttzstellen zur Konzentrationsberechnung
* 18 T0	Startzeit der Immissionskonz.berechnung
* 19 DT	Abstand zu weiteren Sttzstellen
* 20 TS	explizite Vorgabe der Zeiten zu denen gerechnet werden soll
* 21 NZ	Dosis, Maximalkonz. oder Konz.verlauf untersuchen
* 22 XA	Aufpunkt in x-Richtung
* 23 YA	Aufpunkt in y-Richtung
* 24 ZA	Aufpunkt in z-Richtung
*
* 25 MW	nur vorgegebene Ausbreitungssituation berechnen MW>0
*	MW=1,2, oder 3 fr stabil,ind. und labil mit Inversion
*	MW=-1,-2, oder -3 fr stabil,ind. und labil ohne Inversion

* 26 IN Informationslevel (0,1,2)
*------- Kennungen fr schwere Gase
* 27 ST Stoffname (falls Sondergas)
* 28 NU Nummer des Gases
* 29 SI Siedepunkt
* 30 RH Rho
* 31 UZ untere Zndgrenze
* 32 FO Form der Freisetzung
* 33 PR Prozetemperatur
* 34 AU Ausbreitungsgebiet
*-------
* 35 RE	Default-Einstellung aller Eingabeparameter
*	(mu erster Befehl sein, sonst wird er ignoriert)
* 36 GO	starten (BATCH)
* 37 EN Ende der Datei
*
*-----------------------------------------------------------------------
* R*4  AA	Hilfsvariable
* I*4  I	Laufindex
* I*4  IGO	Flag ob Ende der Eingabedatei erreicht
* I*4  IPAR	Nr. der ausgewhlten Variablen
* I*4  IWARN	Fehlerflag
* I*4  K	Index, wenn Kommentarstart Mitten in der Zeile
* I*4  L	Lnge des Textes in STRING
* I*4  LUE	0= keine berhhungsdaten angegeben
*		1= berhhungsdaten angegeben
* I*4  NC	Anzahl der Zeilen mit Zuweisung (auer XA,YA,ZA)
* I*4  NI	Anzahl der vorgegebenen Immissionssttzstellen
* CHAR PAR	Kennung des Parameters (2 Zeichen)
*
* === Felder ===
* R*4  BOUND(2,31) Unter- und Obergrenze des Wertebereichs der
* 		   eingelesenen Variablen
* I*4  KUE(6)	   zhlt die Anzahl der bereits angegebenen Sttzwerte
* 		   (sollte =NQ sein)
* CHAR TERM(36)	   Kennungstext fr die einzelnen einzulesenden Variablen
* R*4  TS(nimi)	   eingelesene Immissionssttzstellen
*(R*4  VAR(9)		vgl. COMMON /INPUT/ UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA)
*(R*4  VARNQ(nemi,6)	vgl. COMMON /INPUT/ TQ,QS,QH,VS,RO,TT)
*
* === aufgerufene Unterprogramme ===
* NBLANK (I*4)
* PARSET
* READSG
* SORT
* WAIT          
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
* QHMIN - minimale Wrmeemission in MW die bercksichtigt werden soll
*	Nach der Richtlinie 6MW.
	PARAMETER (qhmin=6.)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	DIMENSION BOUND(2,32),KUE(6)
	CHARACTER TERM(37)*2,PAR*2

* VARNQ(nemi,6)	== TQ,QS,QH,VS,RO,TT
	COMMON /EMVER/	NQ,VARNQ(nemi,6),
     1			TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)
C	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
C     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ


* VAR(9)	==	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA
	COMMON /INPUT/	VAR(9),
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO


	DATA TERM/'TI','DA','UM','HM','HQ','XQ','YQ','ZQ','XA','YA','ZA',
     1		  'TQ','QS','QH','VS','RO','TT','T0','DT','TS',
     2		  'IZ','NQ','NS','NZ','MW','IN',
     3		  'ST','NU','SI','RH','UZ','FO','PR','AU',
     4		  'RE','GO','EN'/

* -- Wertebereich der einzelnen Parameter --
	DATA BOUND/
*- UM, HM
     B	  1., 10., 0., 9999.,
*- HQ, XQ, YQ, ZQ
     B	  0.,999., 0.,999., 0.,999., 0.,999.,
*- XA,YA,ZA
     B	  1.,9E9, -9E9,9E9, 0.,9E9,
*- TQ
     B	  1.,9E9,
*- QS
     B	  0.,9E9,
*- QH
     B	  0.,9999.,
*- VS
     B	  0.,9E9,
*- RO
     B	  0.,  2.,
*- TT
     B	 10.,9999.,
*- T0
     B	  0.,9E9,
*- DT
     B	  1.,9E9,
*- TS
     B	  0.,9E9,
*- IZ
     B	  1.,  5.,
*- NQ
     B	  1., nemi,
*- NS
     B	  1., nimi,
*- NZ
     B	  0.,  3.,
*- MW
     B	  -3.,  3.,
*- IN
     B	  0.,  2.,
*- ST
     B	  0.,  0.,
*- NU
     B	  0., maxgas,
*- SI
     B    -9E9, 9E9,
*- RH
     B    1.2, 9E9,
*- UZ
     B    -9E9, 9E9,
*- FO
     B	  1.,  4.,
*- PR
     B	  -9E9, 9E9,
*- AU
     B	  1., maxgeb  /

	DATA IWARN/0/

* Initialwerte
	IF (NC.LT.0)	THEN
		UM0=1.
		IGAS=2
		END IF

	NC=0
	NI=0
	LUE=0
	IGO=1
	DO  90  I=1,6
 90	KUE(I)=0

100	READ (11,'(A)',END=500,ERR=500) STRING
	L=NBLANK(STRING)

* Leerzeilen und Kommentarzeilen berspringen
	IF (L.LT.2 .or. STRING(1:1).EQ.'!')	GOTO 100
	PAR(1:2)=STRING(1:2)
* Kleinschreibung umwandeln
* (auf EBCDIC-Rechnern: if (i.lt.170) i=i+64 )
	I=ICHAR(PAR(1:1))
	IF (I.GT.90)	PAR(1:1)=CHAR(I-32)
	I=ICHAR(PAR(2:2))
	IF (I.GT.90)	PAR(2:2)=CHAR(I-32)
*-
	DO  200  IPAR=1,37
	IF (PAR.EQ.TERM(IPAR))	GOTO 220
200	CONTINUE
210	PRINT 1,	STRING(1:L)
  1	FORMAT(/' PAREIN-F-Zeile nicht interpretierbar ?'/
     1	3X,'>>',A,'<<')
	IWARN=1
	GOTO 100

*-- GO, RESET und END haben keine Argumente --------------------------
220	IF (IPAR.EQ.35)	THEN
* RESET der Variablen auf Voreinstellung
		IF (NC.EQ.0)	THEN
			CALL	PARSET
			PRINT 11
 11	FORMAT(' PAREIN-I-Variablen zurckgesetzt')
			UM0=VAR(1)
			NC=NC+1
			ELSE
			IWARN=1
			PRINT 12
 12	FORMAT(' PAREIN-W-RESET ignoriert !')
			END IF
		GOTO 100
		END IF

* GO-Batch
	IF (IPAR.EQ.36)		GOTO 510
* ENd: das war's !
	IF (IPAR.EQ.37)		THEN
		IGO=-1
		GOTO 510
		END IF

*- Ansonsten Argument extrahieren --------------------------------------
	I=INDEX(STRING(1:L),'=')
* wenn keine Zuweisung - Zeile ignorieren
	IF (I.EQ.0)	GOTO 100

* NC zhlt Zuordnungen
	NC=NC+1
*- Textstrings separat behandeln ---------------------------------------
* Titel (max.70 Zeichen)
	IF (IPAR.EQ. 1)		THEN
		TITEL(1:L-I)=STRING(I+1:L)
		GOTO 100
		END IF
* Dateiname (max. 30 Zeichen)
	IF (IPAR.EQ. 2)		THEN
		DATEI(1:L-I)=STRING(I+1:L)
		IAI=1
		GOTO 100
		END IF
* Stoffname (bei schweren Gasen) (max.24 Zeichen)
	IF (IPAR.EQ.27)		THEN
		STNAME(maxgas)(1:L-I)=STRING(I+1:L)
		GOTO 100
		END IF

*------------------------------------------------------------------------
* Kommentar am Ende der Zeile ?
	K=INDEX(STRING(I+1:L),'!')
	IF (K.GT.0)	L=K+I-1

	READ (STRING(I+1:L),2,ERR=210) AA
  2	FORMAT(BN,G20.0)
	IF (INFO.GT.0)	PRINT 99,TERM(IPAR),AA
99	FORMAT(1X,A,' = ',G15.4)

	IPAR=IPAR-2
* Prfung, ob im Wertebereich der Variablen
	IF (AA.LT.BOUND(1,IPAR) .OR. AA.GT.BOUND(2,IPAR)) THEN
		PRINT 3,STRING(1:L),AA,BOUND(1,IPAR),BOUND(2,IPAR)
  3	FORMAT (/' PAREIN-F-Zeile >',A,'< ignoriert'/
     1		9X,'Zahl',G15.5,' nicht im Wertebereich (',G10.1,' -',
     2 		G10.1,')')
		IWARN=1
		GOTO 100
		END IF

* VAR(9) => UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA
	IF (IPAR.LE.9)	THEN
		VAR(IPAR)=AA
		IF (IPAR.EQ.1)	UM0=AA
		IF (IPAR.GE.7)  NC=NC-1
		GOTO 100
		END IF

* Felder (Emissionsabschnitte, Quellstrken und berhhungsparameter)
	IF (IPAR.LT.16)	THEN
		IPAR=IPAR-9
* Wrmeemission direkt angegeben	IW=1
		IF (IPAR.EQ.3)	THEN
			IW=1
			LUE=1
			END IF
* Dichte des Schadgases angegeben
		IF (IPAR.EQ.5)	THEN
			IQ=1
			IW=2
			LUE=1
			END IF
* Schadstofftemp. angegeben		IQ=2
		IF (IPAR.EQ.6)	then
			IQ=2
			IW=2
			LUE=1
			END IF

		KUE(IPAR)=KUE(IPAR)+1
		IF (KUE(IPAR).GT.NQ)	THEN
			PRINT 7,TERM(IPAR+11)
  7	FORMAT(/' PAREIN-F-mehr als NQ Daten fr ',A2)
			IWARN=1
			GOTO 100
			END IF
		VARNQ(KUE(IPAR),IPAR)=AA
		GOTO 100
		END IF

	IF (IPAR.EQ.16)	THEN
		T0=AA
		JST=1
		END IF
	IF (IPAR.EQ.17)	THEN
		DT=AA
		JST=1
		END IF
	IF (IPAR.EQ.18)	THEN
		NI=NI+1
		IF (NI.GT.nimi) STOP 'zuviele Sttzstellen'
		TS(NI)=AA
		END IF

	IF (IPAR.EQ.19)	IZ0=NINT(AA)
	IF (IPAR.EQ.20)	NQ =NINT(AA)
	IF (IPAR.EQ.21)	NTM=NINT(AA)
	IF (IPAR.EQ.22)	NZI=NINT(AA)
	IF (IPAR.EQ.23) MW =NINT(AA)
	IF (IPAR.EQ.24) INFO=NINT(AA)

	IF (IPAR.GT.25)	THEN
*- Kennungen schwerer Gase ---------------------------------------------
		IGAS=1
* Schwergasdaten einlesen
		CALL READSG
		IF (IPAR.EQ.26)	NGAS=NINT(AA)
		IF (NGAS.EQ.0 .OR. NGAS.GT.MGAS)  NGAS=MAXGAS
		IF (IPAR.EQ.27) SIEDP(MAXGAS)=AA
		IF (IPAR.EQ.28) RHONOR(MAXGAS)=AA
		IF (IPAR.EQ.29) UZG(MAXGAS)=AA
		IF (IPAR.EQ.30) NFORM=NINT(AA)
		IF (IPAR.EQ.31) TPROZ=AA
		IF (IPAR.EQ.32) NGEB=NINT(AA)
		END IF
	GOTO 100

* Ende der Eingabedatei erreicht
500	IGO=0

* GO- oder ENd-Befehl erreicht
510	CONTINUE
*- aus Eingabedaten z.B. Wrmeemission berechnen
	IF (LUE.GT.0 .AND. IW.EQ.2)	THEN
* Wrmeemission bestimmen
* CP=.123E-2 - spez. Wrme der Luft bei konst. Druck in MW*s/m**3/K
* BM=0.029   - Molekulargewicht der Luft in kg/Mol
	 IF (IQ.EQ.2)	 THEN
		DO  550  I=1,NQ
550		VARNQ(I,3)=.123E-2*VARNQ(I,4)*(VARNQ(I,6)-10.)
		 ELSE
		DO  570  I=1,NQ
		IF (VARNQ(I,5).GT.0.)
     1		VARNQ(I,3)=.123E-2*VARNQ(I,4)*
     2		(1.2187E4*0.029/VARNQ(I,5)-283.)
570		CONTINUE
	 END IF
	END IF

*- Quellart bestimmen
	LXQ=VAR(4).GE.1.
	LYQ=VAR(5).GE.1.
	LZQ=VAR(6).GE.1.
	IQA=1
	IF (LXQ)	IQA=IQA+1
	IF (LYQ)	IQA=IQA+1
	IF (LZQ)	IQA=IQA+1

*- ist Quellhhe kleiner als Vertikalerstreckung der Quelle, dann
*  wird die Quellhhe auf ZQ gesetzt
	IF (VAR(3).LT.VAR(6))	VAR(3)=VAR(6)

*- Immissionssttzstellen explizit angegeben
	IF (NI.EQ.1)	THEN
		NZI=4
		NTM=1
* (mssen im Normalfall mehr als 3 sein, da sonst keine Dosisberechnung
*  mglich)
		ELSE IF (NI.EQ.2)	THEN
		PRINT 15
 15	FORMAT(
     1	' PAREIN-I-nur eine oder mindestens 3 Sttzstellen angeben')
		IWARN=1
		NTM=1
		ELSE IF (NI.GE.3)	THEN
		NTM=NI
		JST=2
* TS aufsteigend sortieren
		CALL SORT (TS,NI)
		END IF

* mindestens eine erweiterte Option gewhlt
	IF (MW.NE.0 .OR. JST.GT.0)	THEN
		JO=1
		ELSE
		JO=2
		END IF

*- mu berhhung bercksichtigt werden ?
	NUE=1
	DO  600  I=1,NQ
	IF (VARNQ(I,3).GE.qhmin)	GOTO 700
600	CONTINUE
	IF (LUE.EQ.0)	GOTO 650
* wenn der PARAMETER qhmin gendert wird, dieses Format auch ndern
	PRINT 5
  5	FORMAT(/' PAREIN-I-Wrmeemission nicht bercksichtigt (< 6 MW)')
	IWARN=1
650	NUE=2

* wurden die Zeiten nach Emissionsbeginn auch in aufsteigender
* Reihenfolge eingegeben? (macht sonst keinen Sinn)
700	DO  710  I=2,NQ
	IF (VARNQ(I,1).LE.VARNQ(I-1,1))	THEN
		PRINT 9	
  9	FORMAT(' PAREIN-F-Zeitangaben mssen aufsteigend sortiert sein')
		STOP '* Abbruch *'
		END IF
710	CONTINUE

*- im Fall schwerer Gase
	IF (IGAS.EQ.1)	THEN
		IF (NUE.EQ.1)	PRINT 91
 91	FORMAT(/' PAREIN-F-inkompatible Angaben: Schweres Gas und',
     1		' berhhung')
		IQA=1
		LXQ=.FALSE.
		LYQ=.FALSE.
		LZQ=.FALSE.

		ELSE
		IGAS=4-NUE
		END IF

* alte Ausgangsgeschwindigkeit, auch wenn nicht angegeben
	VAR(1)=UM0
* wenn kein GO-Befehl und Variablen gendert
	IF (IPAR.NE.36.AND. NC.GT.0) THEN
* dann wenn Einlesefehler aufgetreten sind anhalten
		IF (IWARN.NE.0)	CALL WAIT
		END IF

	RETURN
	END

	SUBROUTINE	PARSET
*-----------------------------------------------------------------------
* Die im COMMON /INPUT/ stehenden Variablen werden initialisiert:
*-----------------------------------------------------------------------
* UM		1.m/s
* HM		0 m
* HQ		0 m
* XQ,YQ,ZQ	0 m
* XA		100 m
* YA		0 m
* ZA		0 m
* TQ(nemi)	TQ(1)=1s, der Rest ist Null
* Q(nemi)	Q(1)=QS, der Rest ist Null
* QH(nemi)	0 MW
* R(nemi)	0 m**3/s
* RO(nemi)	0 kg/m**3
* TT(nemi)	10C (Auentemperatur)
* TIME(nimi)	Sttzstellen alle 60s beginnend ab 0
* IQ		2
* IW		1
* IZ0		3
* JST		0
* MW		0 (mittl. Ausbreitungssituation ohne Inversion)
* NQ		1
* NUE		keine berhhung
* NTM		10 Sttzstellen
* NZI		0 = alle Immissionsdaten berechnen
* TITEL		70*' '
*- bei schweren Gasen
* IGAS		2 = dichteneutrales Gas
* NGAS		0 = Sondergas
* NGEB		1 = Gebiet ohne Hindernisse
* NFORM		1 = Freisetzungsform
* TPROZ		15 = Prozetemperatur ind Grad C
*-------------------------------
* I*4  I	Laufindex
*----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	parameter (maxgas=40)
	parameter (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO


* INFO		Informationslevel (0-wenig Bildschirmausgabe,
*				   1-berechnete Werte ausgeben,
*				   2-wie 1 + Statuszeile "Rechner luft")
	INFO=1
* IAI	=1	Ergebnisse in Datei abspeichern
	IAI=2
* DATEI		Name der Datei (in diesem Fall der Drucker)
	DATEI='PRN'
* UM		mittlere Windgeschwindigkeit
	UM=1.
* HQ		Quellhhe
	HQ=0.
* HM		Bebauungshhe
	HM=0.
* IZ0		Rauhigkeitsklasse (Z0 = 0.5 m)
	IZ0=3
* XQ,YQ,ZQ	Quelldimensionen
	XQ=0.
	YQ=0.
	ZQ=0.
* NQ		Anzahl der Emissionsabschnitte konstanter Emission
	NQ=1

* NUE	=1	berhhung bercksichtigen
	NUE=2
* NTM		vorgebare Anzahl von Sttzstellen fr die zeitliche
*		Auflsung der Immissionskonzentration
	NTM=10
* NZI	=0	Berechnung aller Immissionsdaten
*	=1	Berechnung der Dosis
*	=2	Berechnung der Maximalkonzentration
*	=3	Berechnung des Konzentrationsverlaufs
*	=4	Berechnung der Konz. an einer Sttzstelle
	NZI=0
* MW	=0	Mittlere Ausbreitungssituation
*		(indifferente Schichtung, keine Inversion)
	MW=0
* XA,YA,ZA	Aufpunkt fr Immissionsberechnung
	XA=100.
	YA=0.
	ZA=0.
* IW	=1	Wrmeemission vorgeben
*	=2	Wrmeemission berechnen
	IW=1

* QH		Wrmeemission fr Zeitintervalle konstanter Emission

* IQ	=1	zur Bestimmung der berhhung wird die Schadstoffdichte
*		angegeben
*	=2	die Schadstofftemperatur wird angegeben
	IQ=2

* JO	=1	erweiterte Optionen
*	=2	nach Richtlinie
	JO=2

* NUR2	=1	nur nach Blatt 2 rechnen
*	=2	Kopplung Blatt1 und Blatt 2
	NUR2=2

* JST		Vorgabe der Immissionsttzstellen
*		0 - nach Beaufschlagungszeiten
*		1 - Vorgabe der Startzeit und des Zeitschritts
*		2 - Vorgabe der Zeiten
	JST=0

* T0,DT		Startzeit und Zeitschritt bei der Vorgabe der Immissions-
*		sttzstellen (falls JST=1)
	T0=0.
	DT=60.

* Felder:
* R		Volumenstrom
* TT		Schadstofftemperatur
* RO		Dichte des Schadstoffes
* TQ		Zeit nach Emissionsbeginn
* Q		Quellstrke
	DO  10  I=1,nemi
	TQ(I)=0.
	Q (I)=0.
	QH(I)=0.
	R (I)=0.
	RO(I)=0.
10	TT(I)=10.

	TQ(1)=1.
	Q (1)=1.

* berschrift lschen
	DO  20  I=1,70
20	TITEL(I:I)=' '

* Vorschlag fr die Zeiten zu denen die Immission berechnet werden soll
* (nur wenn JST=2)
	DO  30  I=1,nimi
30	TIME(I)=(I-1)*60.

* dichteneutrales Gas
	IGAS=2
*--- bei schweren Gasen ---
* Name des Gases
	STNAME(maxgas)='Sondergas'
* Schwergasausbreitung nach Blatt 2 (IERR=0), sonst nach Blatt 1
	IERR=0
* Sondergas
	NGAS=0
* Gebiet ohne Hindernisse
	NGEB=1
* Freisetzungsform
	NFORM=1
* Prozetemperatur ind Grad C
	TPROZ=15.
* Siedepunkt, Dichte bei Normalbedingungen, untere Zndgrenze
	SIEDP(maxgas)=0.
	RHONOR(maxgas)=0.
	UZG(maxgas)=-1.

	RETURN
	END

	SUBROUTINE	DISPI (Version)
*-----------------------------------------------------------------------
* Einfhrungsbildschirme
*-----------------------------------------------------------------------
* === aufgerufene Unterprogramme ===
* CLS
* FRAME
* WAIT          
*-----------------------------------------------------------------------
	CALL	CLS
	PRINT 1,Version
 1	FORMAT(
     1	' ',77(''),''/
     2	' ',T25,	'Strfallprogramm STOER V',F4.2,	T80,''/
     3	' ',18X, 'zur Strfallverordnung VDI 3783 Blatt 1+2',	T80,''/
     4	' ',77(''),''///)

	PRINT 2
 2	FORMAT(' ',77(''),''/
     1'   Dieses  Programm  berechnet an einem vorzugebenden Aufpunkt',
     1' den Konzen-',T80,''/
     2'   trationsverlauf, die Maximalkonzentration oder die Dosis',
     2' fr eine zeit-',T80,''/
     3'   abhngig emittierende Punkt-, Linien-, Flchen-  oder',
     3' Volumenquelle.',T80,''/
     4'   Betrachtet wird eine mittlere und die "ungnstigste"',
     4' Ausbreitungssituation.',T80,''/
     5'   Dichteneutrale und leichte (heie) Gase werden nach  Blatt',
     5' 1 behandelt.',T80,''/
     6'   Bei  schweren Gasen wird nach  Blatt 2 gekoppelt,  d.h.',
     6' nach Beendigung',T80,''/
     7'   der Schwergasphase  wird mit einem dichteneutralen',
     7' Gasgemisch von einer',T80,''/
     8'   Punktquelle aus weitergerechnet.',T80,''/
     9' ',77(''),'')

	PRINT 3
 3	FORMAT(
     1	'   Es wird dringend angeraten, vor der Durchfhrung von'
     2	' Sicherheitsanalysen',T80,''/
     3	'   mit diesem Programm, die Texte der Richtlinie VDI 3783',
     4	' Blatt 1 und 2 so-',T80,''/
     5	'   wie die Benutzeranweisung zu diesem Programm durchzuar',
     6	'beiten.',T80,''/
     9  ' ',77(''),'')

	CALL WAIT

	CALL FRAME ('Hinweise zur Eingabetechnik')
	PRINT 5
  5	FORMAT(' ',77(''),''/' ',T80,''/
     1	'  Bei dem Zeichen  >  wird eine Eingabe erwartet.',
     2	' Mgliche Eingaben sind:',T80,''/' ',T80,''/
     3	'   <RETURN>  -  der voreingestellte Wert wird bernommen',T80,
     4	''/
     5	'     Zahl    -  diese Zahl wird genommen, sofern sie in den',
     6	' Grenzen liegt',T80,''/
     7  '   J oder j  -  als Antwort fr JA',T80,''/
     8  '   N oder n  -  als Antwort fr NEIN',T80,''/' ',T80,'')

	PRINT 6
  6	FORMAT('  Bei zwei  >>  sind als Eingabe mglich:',T80,''/
     1	' ',T80,''/
     2	'   <RETURN>  -  die voreingestellten Werte werden bernommen',
     3	T80,''/
     4	'   Zahl1,Zahl2   oder   Zahl1,   oder  ,Zahl2',T80,''/
     5	' ',T80,''/
     6	'  Bei ungltigen Angaben wird die Frage wiederholt.',T80,''/
     7	'  Existiert eine Datei  STOER.INI  im aktuellen Verzeichnis,',
     8	T80,''/'  dienen diese Daten zur Initialisierung.',T80,''/
     9	' ',T80,''/' ',77(''),'')

	CALL WAIT

	RETURN
	END

	SUBROUTINE	SGPAR
*-----------------------------------------------------------------------
* Interkatives Einlesen der Schwergasparameter
*-----------------------------------------------------------------------
* I*4  I	Laufindex
* I*4  K	Laufindex
* === aufgerufene Unterprogramme ===
* FRAME
* GET1I
* GET1R
* READSG
* WAIT
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	LOGICAL LCORR

* Schwergasdaten einlesen
	CALL READSG

*------ Gasauswahl -----------------------------------------------------
100	CALL FRAME ('Schwergasparameter')

	DO 110 I=1,10
110	PRINT 2, I,STNAME(I),I+10,STNAME(I+10),I+20,STNAME(I+20)
  2	FORMAT (I3,'=',A23,I3,'=',A23,I3,'=',A22)

	DO 120 I=31,MGAS,3
120	PRINT 2, (I+K,STNAME(I+K),K=0,MIN0(2,MGAS-I))

	PRINT 3, maxgas
  3	FORMAT(/I3,'=anderes Gas')

	PRINT 4, NGAS
  4	FORMAT(//' Nummer des Gases',T50,I6,T70,'> '\)
	CALL GET1I (NGAS,1,maxgas,*999)

*----------------------------------------------------------------------
* Sondergas
*----------------------------------------------------------------------
	IF (NGAS.GE.maxgas .OR. NGAS.EQ.0) THEN
	NGAS=maxgas
*----- Abfragen fr sonstige Gase (Sondergas) -------------------------
	CALL FRAME ('Sondergasspezifikation')
* Die Eingabe des Siedepunkts wird nur bei
* unter Druck verflssigtem Gas bercksichtigt
200	PRINT 5, STNAME(maxgas)
  5	FORMAT(/' Name des Gases:',T30,A,T55,'> '\)
	READ (*,'(A)',END=999,ERR=200) STRING
	IF (STRING(1:1).NE.' ') STNAME(maxgas)=STRING(1:24)

	PRINT 6, SIEDP(maxgas)
  6	FORMAT(/' Siedepunkt [Grad C]:',T40,F10.1,T55,'> '\)
	CALL GET1R (SIEDP(maxgas),-9999.,9999.,*999)

	PRINT 7, RHONOR(maxgas)
  7	FORMAT(/' Normdichte (0C,1013hPa) in [kg/m**3]:',
     1        T40,F10.4,T55,'> '\)
	CALL GET1R (RHONOR(maxgas),0.,9999.,*999)

210	print 8, UZG(maxgas)
  8	FORMAT(/' Untere Zndgrenze [Vol%]: '/T40,F10.4,T55,'> '\)
	CALL GET1R (UZG(maxgas),-9999.,9999.,*999)
	IF (UZG(maxgas).GT.0. and. UZG(maxgas).LT.1.) THEN
		PRINT 28
 28	FORMAT(/' Die untere Zndgrenze mu grer gleich 1% sein!')
		UZG(maxgas)=1.
		GOTO 210
		END IF

	END IF

*----------------------------------------------------------------------
* Abfrage der Freisetzungsform
*----------------------------------------------------------------------
	CALL FRAME ('In welcher Form wird das Gas freigesetzt?')
	PRINT 9,(I,FORM(I),I=1,4)
  9	FORMAT (I3,' = ',A64)

	PRINT 11, NFORM
 11	FORMAT (/' Freisetzungsform',T54,I1,T59,'> '\)
	CALL GET1I (NFORM,1,4,*999)

	IF (NGAS.EQ.4 .AND. NFORM.NE.4) THEN
		PRINT 12
 12		FORMAT (/
     1' !!  Ammoniak breitet sich nur dann als schweres Gas aus, wenn',
     1' es unter'/
     2' !!  Druck verflssigt freigesetzt wird (Option 4). In allen'
     2' ,anderen Fllen'/
     3' !!  knnen Ammoniakstrflle direkt mit der Richtlinie VDI 3783',
     3' -Blatt 1-'/
     4' !!  berechnet werden.'/)
		NFORM=4
		PRINT 11,NFORM
		CALL GET1I (NFORM,1,4,*999)
		IF (NFORM.NE.4)		THEN
			IGAS=2
			PRINT 91
 91	FORMAT(' !! Dieser Fall wird nach Blatt 1 gerechnet.')
			CALL WAIT
			RETURN
			END IF
		END IF

*----------------------------------------------------------------------
* Abfrage der Prozetemperatur
*----------------------------------------------------------------------
	IF (NFORM.EQ.2) PRINT 13, STNAME(NGAS),SIEDP(NGAS)
 13	FORMAT(/
     1' Drucklos verflssigte Gase sind auf oder unter den Siedepunkt',
     1' abgekhlt.'/
     2' Das verdampfte Gas hat daher Prozetemperatur, maximal',
     2' Siedetemperatur.'/
     3' Die Siedetemperatur von ',A,' betrgt',F6.1,' Grad C.')

	IF (NFORM.LE.2) THEN
		PRINT 14, TPROZ
 14	FORMAT (/' Prozetemperatur in Grad C',T50,G10.4,T59,'> '\)
		CALL GET1R (TPROZ,-9999.,9999.,*999)
		END IF

*----------------------------------------------------------------------
* Abfrage des Ausbreitungsgebiets
*----------------------------------------------------------------------
	CALL FRAME ('Ausbreitungsgebiet')

	DO 250 I=1,(mgeb+1)/2
	PRINT 16,I,GEBIET(I),I+(mgeb+1)/2,GEBIET(I+(mgeb+1)/2)
250	CONTINUE
 16	FORMAT (I3,' = ',A32,T40,I3,' = ',A32)

	PRINT 17, NGEB
 17	FORMAT (/' Kennung des Gebiets',T45,I2,T50,'> '\)
	CALL GET1I (NGEB,1,MGEB,*999)

*----------------------------------------------------------------------
* Abfrage des Ausbreitungsgebiets
*----------------------------------------------------------------------
	CALL FRAME ('Nur Schwergasphase rechnen')

	PRINT 18, JANEIN(NUR2)
 18	FORMAT (/' Nur Rechnung nach Blatt 2',T45,A5,'> '\)
	CALL GETJN (NUR2,*999)

*----------------------------------------------------------------------
* Anzeige der eingestellten Werte
*----------------------------------------------------------------------
999	CALL FRAME ('Schwergasparameter')

	PRINT 19,STNAME(NGAS),SIEDP(NGAS),RHONOR(NGAS)
 19	FORMAT (' Gasart:',T24,A24//
     1		' Siedepunkt:',T24,F6.1,' Grad C'/
     2		' Normdichte:',T24,F6.2,' kg/m**3')
 20	FORMAT (' untere Zndgrenze:',T24,F6.1,' Vol%')
	IF (UZG(NGAS).GT.0)	PRINT 20,UZG(NGAS)
	IF (NFORM.LE.2)		PRINT 21,TPROZ
 21	FORMAT (' Prozetemperatur:',T24,F6.1,' Grad C'/)
	PRINT 22,FORM(NFORM)(1:30),GEBIET(NGEB)
 22	FORMAT (' Freisetzungsform:',  T24,A/
     1		' Ausbreitungsgebiet:',T24,A)
* sollen Werte abgendert werden
	IF (LCORR())	GOTO 100
	RETURN
	END

	LOGICAL FUNCTION LCORR ()
*-----------------------------------------------------------------------
* LOGICAL-Function liefert .TRUE. wenn Korrekturen gemacht werden
* sollen, ansonsten .FALSE.
*
* L*4  LCORR	Argument
* I*4  IOK	1 - Werte ndern, 2 - weiter ohne nderung
* === aufgerufene Unterprogramme ===
* GETJN         
*-----------------------------------------------------------------------

	PRINT 1,27,24,0
  1	FORMAT (1X,A1,'[',I2,';',I1,'H-- Werte ndern?',T50,'nein  > '\)
	IOK=2
	CALL GETJN (IOK,*999)
	LCORR=IOK .EQ. 1

999	RETURN
	END

	SUBROUTINE	READSG
*-----------------------------------------------------------------------
* Daten fr Schwergasausbreitung einlesen
*-----------------------------------------------------------------------
* Die Dateien GASE.DAT und VERSATZ.DAT mssen im aktuellen Verzeichnis
* oder im Verzeichnis C:\STOER\ stehen.
*
* L*4  DEJAVU	Kennung, ob Dateien bereits eingelesen
* I*4  I	Laufindex
* I*4  K	Laufindex
* I*4  M	Laufindex
* I*4  IN	Laufindex
* CHAR Z	ein Zeichen um Kommentare zu berlesen
*-----------------------------------------------------------------------
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING


	CHARACTER	Z*1
	LOGICAL		DEJAVU
	DATA		DEJAVU/.FALSE./

	IF (DEJAVU)	RETURN
	DEJAVU=.TRUE.

*----------------------------------------------------------------------
* Stoffnamen und phys.Gren einlesen
*----------------------------------------------------------------------
	OPEN (UNIT=77,FILE='GASE.DAT',STATUS='OLD',ERR=900)
	GOTO 10
900	OPEN (UNIT=77,FILE='C:\STOER\GASE.DAT',STATUS='OLD',ERR=910)
	GOTO 10
910	PRINT 91,'GASE'
 91	FORMAT(/' !! Datei ',A,'.DAT weder im aktuellen noch im'
     1		' Verzeichnis C:\STOER\ gefunden.'/)
	STOP '* Abbruch *'

 10	READ (77,'(A1)') Z
	IF (Z.NE.'-')	GOTO 10
	DO  20  I=1,maxgas
 20	READ (77,77,END=40) STNAME(I),SIEDP(I),RHONOR(I),UZG(I)
 77	FORMAT(A24,3F7.2)
 40	CLOSE (UNIT=77)
	MGAS=I-1

*----------------------------------------------------------------------
* Daten fr Kopplung (Tabelle 2 der Richtlinie)
*----------------------------------------------------------------------
	OPEN (UNIT=88,FILE='VERSATZ.DAT',STATUS='OLD',ERR=950)
	GOTO 50
950	OPEN (UNIT=88,FILE='C:\STOER\VERSATZ.DAT',STATUS='OLD',ERR=960)
	GOTO 50
960	PRINT 91,'VERSATZ'
	STOP '* Abbruch *'

 50	READ (88,'(A1)') Z
	IF (Z.NE.'-')	GOTO 50
	DO  60  I=1,maxgeb
	READ (88,'(A32)',END=90) GEBIET(I)
 60	READ (88,88,END=90)	DXI(1,I),DXI(2,I),
     1				DTI(1,I),DTI(2,I),
     2				DXC(1,I),DXC(2,I)
 88	FORMAT(6F5.0)
 90	CLOSE (UNIT=88)
	MGEB=I-1

*----------------------------------------------------------------------
* Daten fr die untere Zndgrenze (Tabelle 2 der Richtlinie)
*----------------------------------------------------------------------
	OPEN (UNIT=99,FILE='ZNDIST.DAT',STATUS='OLD',ERR=970)
	GOTO 150
970	OPEN (UNIT=99,FILE='C:\STOER\ZNDIST.DAT',STATUS='OLD',ERR=980)
	GOTO 150
980	PRINT 91,'ZNDIST'
	STOP '* Abbruch *'

150	READ (99,'(A1)') Z
	IF (Z.NE.'-')	GOTO 150
	DO  160  I=1,maxgeb
	READ (99,'(A1)',END=190)
	READ (99,'(A32)',END=190) GEBIET(I)
* I   - Ausbreitungsgebiet
* M=1 - Mittelw., M=2 - Max.
* K=1 - spontan , K=2 - kontinuierlich
	READ (99,99,END=190)  (((UZDAT(IN,M,K,I),IN=1,15),
     1				(UCDAT(IN,M,K,I),IN=1,15),M=1,2),K=1,2)
 99	FORMAT(15F7.2)
160	CONTINUE
190	CLOSE (UNIT=99)

	RETURN
	END

	SUBROUTINE	EMPAR
*-----------------------------------------------------------------------
* Abfrage des Emissionsverlaufs
*
* I*4  I	Laufindex
* === aufgerufene Unterprogramme ===
* FRAME
* GET1I
* GET1R
* LCORR (L*4)
* PARS2
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	LOGICAL LCORR

*-----------------------------------------------------------------------
100	CALL FRAME ('Emissionsverlauf')
	PRINT 1,nemi
  1	FORMAT(' ',77(''),''/
     1'  Es lassen sich 3 Arten des Emissionsverlaufs angeben:',
     1	T80,''/' ',T80,''/
     2'    spontan        - 1 Emissionsabschnitt mit hchstens 1 s',
     2' Dauer.'T80,''/
     3'    kontinuierlich - 1 Emissionsabschnitt mit mindestens 2 s',
     3' Dauer.'T80,''/
     4'    variabel       - Maximal',I3,' Abschnitte beliebiger',
     4' Dauer.'T80,''/
     5' ',77(''),'')

* Im Fall schwerer Gase trifft das Programm die Entscheidung,
* ob der Strfall als spontan oder kontinuierlich behandelt wird.

*----------------------------------------------------------------------
* Abfrage der Anzahl der Abschnitte konstanter Emission
*----------------------------------------------------------------------

	PRINT 2, nemi,NQ,'>'
  2	FORMAT(/' Emissionsabschnitte [1-',I3,']:',T50,I5:T70,A1\)
	CALL	GET1I (NQ,1,nemi,*999)

* nur 1 Abschnitt
	IF (NQ.EQ.1)	THEN
		PRINT 3, TQ(1),'>'
  3		FORMAT(' Emissionsdauer:',T50,F6.0,' s':T70,A1\)
		CALL	GET1R (TQ(1),1.,0.,*999)

		IF (TQ(1).LE.1. .AND. IGAS.EQ.1)	THEN
* spontane Emission
			PRINT 44,Q(1),'>'
 44	FORMAT (' Freigesetzte Masse ohne Lachenanteil',T41,G15.4,
     &           ' g':T70,A1\)
			ELSE
			PRINT 4, Q(1),QUEDIM(IQA),'>'
  4		FORMAT(' Quellstrke',T41,G15.4,A:T70,A1\)
			END IF
		CALL	GET1R (Q(1),0.,0.,*999)
		ELSE

* mehrere Abschnitte
		PRINT 5, QUEDIM(IQA)
  5		FORMAT (' Sttz-        Zeit nach       Quellstrke'/
     1			' stelle     Emissionsbeginn'/
     2			'                  [s]           [',A,']')
		DO 210 I=1,NQ
180		PRINT 6, I,TQ(I),Q(I),'>>'
  6		FORMAT (1X,I3,11X,F6.1,6X,G15.4:T50,A2\)
		CALL PARS2 (TQ(I),Q(I),*999)
		IF (TQ(I).EQ.0.) THEN
			PRINT 91
 91			FORMAT(
     1' !! Zeit nach Emissionsbeginn mu grer als 0 s sein !!')
			GOTO 100
			END IF
		IF (I.GT.1 .AND. (TQ(I).LT.TQ(I-1))) THEN
			PRINT 92
 92	FORMAT(' !! Zeitangaben mssen aufsteigend sortiert sein !!')
			GOTO 180
			END IF
210		CONTINUE
		END IF

*----------------------------------------------------------------------
* eingestellte Werte anzeigen
*----------------------------------------------------------------------
	CALL FRAME ('Emissionsverlauf')

	PRINT 2, nemi,NQ

	IF (NQ.EQ.1)	THEN
		PRINT 3, TQ(1)
		IF (TQ(1).LE.1. .AND. IGAS.EQ.1)	THEN
			PRINT 44, Q(1)
			ELSE
			PRINT 4,  Q(1),QUEDIM(IQA)
			END IF
		ELSE
		PRINT 5, QUEDIM(IQA)
		DO 530 I=1,NQ
530		PRINT 6, I,TQ(I),Q(I)
		END IF

	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	UEPAR
*-----------------------------------------------------------------------
* berhhungsdaten einlesen
*
* I*4  I	Laufindex
* === aufgerufene Unterprogramme ===
* FRAME
* GET1R
* GETJN
* LCORR (L*4)
* PARS2
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
* QHMIN - minimale Wrmeemission in MW die bercksichtigt werden soll
*	Nach der Richtlinie 6MW.
	PARAMETER (qhmin=6.)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL LCORR

*-----------------------------------------------------------------------
	NUE=1

100	CALL FRAME ('Angaben zur Wrmeemission')
	PRINT 21
 21	FORMAT(' ',77(''),''/
     1'  Nach der Richtlinie wird eine berhhung der Abgasfahne erst'
     1' bercksichtigt,',T80,''/
     2'  wenn die Wrmeemission in mind. einem Zeitabschnitt mehr',
     2' als 6 MW betrgt.',T80,''/
     3  ' ',77(''),''/)
* Wrmeemission fr berhhungsberechnungen bestimmen
	PRINT 1, JANEIN(IW),'>'
  1	FORMAT(' Wrmeemission direkt angeben',T50,A5:T70,A1\)
	CALL GETJN (IW,*999)
	IF (IW.EQ.1)	THEN

*----------------------------------------------------------------------
* Wrmeemission direkt angeben !
*----------------------------------------------------------------------
		IF (NQ.EQ.1)	THEN
			PRINT 2, QH(1),'>'
  2	FORMAT(' Wrmeemission',T49,F6.1,' MW':T70,A1\)
			CALL	GET1R (QH(1),qhmin,0.,*999)
			ELSE
			PRINT 3
  3	FORMAT( ' Sttz-    Wrmeemission'/
     1		' stelle         [MW]')
			DO  200  I=1,NQ
			PRINT 4, I,QH(I),'>'
  4	FORMAT(1X,I3,T12,F6.1:T70,A1\)
			CALL	GET1R (QH(I),0.,0.,*999)
200			CONTINUE
			END IF
		GOTO 400
		END IF

*----------------------------------------------------------------------
* Wrmeemission ber Temperatur und Volumenstrom
*----------------------------------------------------------------------
	PRINT 6, JANEIN(IQ)
  6	FORMAT(' wird die Schadstoffdichte eingegeben',T50,A5,T70,'>'\)
	CALL GETJN (IQ,*999)
	IF (IQ.EQ.2)	THEN

		PRINT 7
  7	FORMAT (' Sttz-   Volumenstrom  Schadstofftemperatur'/
     1		' stelle     [m**3/s]         [Grad C]')
		DO  250  I=1,NQ
220		PRINT 8, I,R(I),TT(I)
  8	FORMAT(I4,8X,F6.2,9X,F5.1,T50,'>>'\)
		CALL PARS2 (R(I),TT(I),*999)
*  Berechnung der Wrmeemission
*  CP=.123E-2 - spez. Wrme der Luft bei konst. Druck in MW*s/m**3/K
		QH(I)=.123E-2*R(I)*(TT(I)-10.)
		IF (QH(I).LE.0.)	THEN
			PRINT 95, QH(I)
			GOTO 220
			END IF
250		CONTINUE
		GOTO 400
		ELSE

*----------------------------------------------------------------------
* Wrmeemission ber Schadstoffdichte und Volumenstrom
*----------------------------------------------------------------------
		PRINT 11
 11	FORMAT (' Sttz-   Schadstoffdichte  Volumenstrom'/
     1		' stelle      [kg/m**3]        [m**3/s]')
 12	FORMAT(I4,10X,F6.3,12X,F6.1,T50,'>>'\)
		DO  300  I=1,NQ
270		PRINT 12, I,RO(I),R(I)
		CALL PARS2 (RO(I),R(I),*999)
* Berechnung der Wrmeemission
* BM=0.029 - Molekulargewicht der Luft in kg/Mol
		QH(I)=.123E-2*R(I)*(1.2187E4*0.029/RO(I)-283.)
		IF (QH(I).LT.0.)	THEN
			PRINT 95, QH(I)
 95	FORMAT (' !! falsche Wrmeemission = ',G15.4,' MW ?')
			GOTO 270
			END IF
300		CONTINUE
		END IF

*----------------------------------------------------------------------
* Ist die Wrmeemission in einem Emissionsabschnitt grer
*----------------------------------------------------------------------
*----- als QHMIN (=6MW) ?
400	DO  420  I=1,NQ
	IF (QH(I).GE.qhmin)	GOTO 490
420	CONTINUE

	PRINT 96
 96	FORMAT(' !! Max. Wrmeemission kleiner als 6 MW')
* wenn der PARAMETER qhmin gendert wird dieses Format auch ndern

C	PRINT 22,JANEIN(1)
C 22	FORMAT(' also berhhung nicht bercksichtigen',T50,A5,T70,'>'\)
C	IQ=1
C	CALL GETJN (IQ,*999)
C	IF (IQ.EQ.2)		GOTO 100
* keine berhhung
	NUE=2

*----------------------------------------------------------------------
* eingestellte Werte anzeigen
*----------------------------------------------------------------------
490	CALL FRAME ('Angaben zur Wrmeemission')

	PRINT 1, JANEIN(IW)
	IF (NQ.EQ.1)	THEN
		PRINT 2, QH(1)
		ELSE
		PRINT 3
		DO 500 I=1,NQ
500		PRINT 4, I,QH(I)
		END IF
	IF (NUE.EQ.2)	PRINT 21

	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	SOPAR
*-----------------------------------------------------------------------
* weitere Standortparameter
*-----------------------------------------------------------------------
* mittlere Windgeschwindigkeit in Anemometerhhe
* mittlere Gebudehhe
* Bodenrauhigkeit
* === aufgerufene Unterprogramme ===
* FRAME
* GET1I
* GET1R
* LCORR (L*4)  
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	COMMON /CONST/	Z0I(5),PI,W2PI,DW2PI,DW2PI3,WPIH,W2

	LOGICAL LCORR

*-----------------------------------------------------------------------
100	CALL FRAME ('Standortparameter')

	UM=UM0
	PRINT 2, UM,'>'
  2	FORMAT(/' mittlere Windgeschwindigkeit:',T50,F5.1,' m/s':
     1		T70,A1\)
* Wertebereich fr Windgeschwindigkeiten von 1m/s bis 10m/s
	CALL	GET1R (UM,1.,10.,*999)
	UM0=UM

	PRINT 3, HM,'>'
  3	FORMAT(/' Bebauungshhe:',T50,F5.1,' m':T70,A1\)
	CALL	GET1R (HM,0.,9999.,*999)

	PRINT 4, IZ0,Z0I(IZ0),'>'
  4	FORMAT(/' Rauhigkeitsklasse:',T50,I5,' (Z0=',F4.2,'m)':T70,A1\)
	CALL	GET1I (IZ0,1,5,*999)
	Z0=Z0I(IZ0)
* Quellhhe ist mindestens Z0
	IF (HQ.LT.Z0)	HQ=Z0

*----------------------------------------------------------------------
* Eingestellte Werte anzeigen
*----------------------------------------------------------------------
	CALL FRAME ('Standortparameter')
	PRINT 2, UM
	PRINT 3, HM
	PRINT 4, IZ0,Z0I(IZ0)
	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	QGPAR
*-----------------------------------------------------------------------
* Quellgeometrie einlesen
* === aufgerufene Unterprogramme ===
* FRAME
* GET1R
* LCORR (L*4)
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL LCORR

*-----------------------------------------------------------------------
100	CALL FRAME ('Quellgeometrie')
	PRINT 1, XQ,'>'
  1	FORMAT(/' Quelldimensionen:',T46,'XQ=',F6.1,' m':T70,A1\)
	CALL	GET1R (XQ,0.,1000.,*999)
	PRINT 2, 'YQ',YQ,'>'
  2	FORMAT(T46,A2,'=',F6.1,' m':T70,A1\)
	CALL	GET1R (YQ,0.,1000.,*999)
	PRINT 2, 'ZQ',ZQ,'>'
	CALL	GET1R (ZQ,0.,1000.,*999)

* nur bercksichtigen, wenn Ausdehnung mindestens 1m betrgt
	LXQ=XQ.GE.1.
	LYQ=YQ.GE.1.
	LZQ=ZQ.GE.1.
	IQA=1
	IF (LXQ)	IQA=IQA+1
	IF (LYQ)	IQA=IQA+1
	IF (LZQ)	IQA=IQA+1

	IF (HQ.LT.ZQ)	HQ=ZQ
	PRINT 3, HQ,'>'
  3	FORMAT(' Quellhhe:',T50,F5.1,' m':T70,A1\)
* Quellhhe mindestens in Z0
	CALL	GET1R (HQ,Z0,1000.,*999)

	IF (ZQ.GT.HQ)	THEN
		PRINT 91
 91	FORMAT(' !! Quellhhe mu mindestens gleich der Hhe der',
     1' Oberkante der Quelle sein !!')
		GOTO 100
		END IF

*----------------------------------------------------------------------
* eingestellte Werte anzeigen
*----------------------------------------------------------------------
	CALL FRAME ('Quellgeometrie')
	PRINT 1, XQ
	PRINT 2, 'YQ',YQ
	PRINT 2, 'ZQ',ZQ
	PRINT 3, HQ
	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	XOPAR
*-----------------------------------------------------------------------
* Erweiterte Optionen, d.h. Mglichkeiten, die ber die Richtlinie 
* hinausgehen
*-----------------------------------------------------------------------
* I*4  I	Laufindex
* I*4  INV	Flag ob Berechnung einer vorgegebenen Wetterlage mit
*		oder ohne Inversion gerechnet werden soll (1=ohne,2=mit)
* === aufgerufene Unterprogramme ===
* FRAME
* GET1I
* GET1R
* GETJN
* LCORR (L*4)
* PARS2
* SORT
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL LCORR

*-----------------------------------------------------------------------
100	CALL FRAME ('Weitere Optionen')

	INV=2
	IF (MW.GT.0) INV=1
	MW=IABS(MW)
	PRINT 2
  2	FORMAT( ' soll nur eine bestimmte Ausbreitungssituation',
     1		' gerechnet werden?')
	PRINT 3, MW,'>'
  3	FORMAT(/
     1	'  0 - ind. Schichtung ohne Inversion und alle Schichtungen', 
     1	' mit Inversion'/
     2	'  1 - nur stabile Schichtung'/
     3	'  2 - nur indifferente Schichtung'/
     4	'  3 - nur labile Schichtung'/
     5	1X,T50,'  (',I1,')':T70,A1\)
	CALL	GET1I (MW,0,3,*999)

	IF (MW.EQ.1 .AND. UM.GT.6 .OR.
     1	    MW.EQ.3 .AND. UM.GT.7)	THEN
		PRINT 93
 93	FORMAT(' !! Bei der angegebenen Windgeschwindigkeit tritt,'
     1' diese Schichtung '/' !! nicht mehr auf.  MW auf 2 gesetzt !')
		MW=2
		END IF

* soll die vorgegebene Ausbreitungssituation mit oder ohne Inversion
* gerechnet werden
	IF (MW.GT.0)	THEN
		PRINT 4,JANEIN(INV)
  4		FORMAT(/' soll mit Inversion gerechnet werden?',
     1		T50,A5,T70,'>'\)
		CALL GETJN (INV,*999)
		IF (INV.EQ.2)	MW=-MW
		END IF

	PRINT '(1H )'
* wenn NZI=4 nur eine Sttzstelle berechnen. Zeitpunkt bereits
* eingelesen
	IF (NZI.EQ.4)	RETURN

	PRINT 5
  5	FORMAT(' Vorgabe der Immissionssttzstellen')
	PRINT 6, JST,'>'
  6	FORMAT(/'  0 - Berechnung ber Beaufschlagungszeiten'/
     1		'  1 - Vorgabe der Startzeit und des Zeitschritts'/
     2		'  2 - Vorgabe einzelner Zeiten'/
     3	1X,T50,'  (',I1,')':T70,A1\)
	CALL	GET1I (JST,0,2,*999)

* 2 Mglichkeiten der Vorgabe unterscheiden
	IF (JST.EQ.1) THEN
200		PRINT 7,T0,DT,'>'
  7	FORMAT(/' Startzeit und Zeitschritt (s):',F8.1,',',F5.1:T50,
     1	A1\)
		CALL PARS2 (T0,DT,*999)
		IF (T0.LT.0. .OR. DT.LE.0.)	GOTO 200
		DO  250  I=1,nimi
250		TIME(I)=T0+(I-1)*DT
		NTM=nimi
		TTD=DT
		ELSE IF (JST.EQ.2) THEN
* Explizite Vorgabe der Zeit(en) fr die Sttzstellen
		DO  260  I=1,NTM
		PRINT 8,I,TIME(I)
  8		FORMAT(I5,F10.1,' s     > ',\)
		CALL	GET1R (TIME(I),0.,0.,*999)
260		CONTINUE
* die Eingaben sortieren, da sonst falsche Dosisberechnung mglich
		CALL SORT (TIME,NTM)
		TTD=0.
		END IF

*----------------------------------------------------------------------
* eingestellte Werte anzeigen
*----------------------------------------------------------------------
C	CALL FRAME ('Weitere Optionen')
	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	GOPAR
*-----------------------------------------------------------------------
* Steuerparameter
* === aufgerufene Unterprogramme ===
* FRAME
* GET1I
* GET1R
* GETJN
* LCORR (L*4)
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL LCORR

*-----------------------------------------------------------------------
100	CALL FRAME ('Steuerparameter')

110	PRINT 2, NTM,'>'
  2	FORMAT(' Konzentrationsberechnung an NS Sttzstellen',
     1	T50,I5:T70,A1\)
	CALL	GET1I (NTM,1,nimi,*999)
	IF (NTM.EQ.2)	THEN
		PRINT 91
 91	FORMAT(' !! nur eine oder mindestens 3 Sttzstellen !!')
		NTM=1
		GOTO 110
		END IF

* wenn NS=1, dann nur fr eine Zeit die Konzentration bestimmen
	IF (NTM.EQ.1)	THEN
		PRINT 3, TIME(1),'>'
  3	FORMAT(' Zeitpunkt in [s] nach Emissionsbeginn',T48,F7.1,' s':
     1	T70,A1\)
		CALL	GET1R (TIME(1),1.,0.,*110)
		NZI=4
		RETURN
		ELSE IF (NZI.EQ.4)	THEN
		NZI=0
		END IF
*-------
	PRINT 4, NZI,'>'
  4	FORMAT(/' Untersuchung',
     1	T15,' (0) aller 3 Mglichkeiten'/
     2	T15,' (1) der Dosis'/
     3	T15,' (2) der Maximalkonzentration'/
     4	T15,' (3) des Konzentrationsverlaufes'/
     5	1X,T50,'  (',I1,')':T70,A1\)
	CALL	GET1I (NZI,0,3,*999)

*--- erweiterte Optionen ---
	PRINT 5, JANEIN(JO)
  5	FORMAT(/' weitere Optionen einstellen':T50,A5,T70,'>'\)
	CALL GETJN (JO,*999)

*------ eingestellte Werte anzeigen -----------------------------------
C	CALL FRAME ('Steuerparameter')
	IF (LCORR())	GOTO 100

999	RETURN
	END

	SUBROUTINE	SGPHAS (BATCH)
*-----------------------------------------------------------------------
* Schwergasphase rechnen
*-----------------------------------------------------------------------
* Bestimmung des Kopplungspunktes bei SPONTANER und KONTINUIERLICHER
* Freisetzung
*-----------------------------------------------------------------------
* Die folgenden Gren geben die Quellentfernung und den zeitlichen 
* Versatz an, bei denen die Konzentration auf 1% der Anfangsvolumen-
* konzentration abgesunken ist.
* D_I - spontane Freisetzung
* D_C - kontinuierliche Freisetzung
* Index I=1 - Mittelwerte, I=2 - Mittelwerte+2RMS
* Index J=1,maxgeb - im Windkanal ermittelte Daten
* DXI(I,J) - Quellversatz in char. Lngeneinheiten
* DTI(I,J) - Zeitversatz in char. Zeiteinheiten
* DXC(I,J) - Quellversatz in char. Lngeneinheiten
*
* I*4  K	Laufindex
* R*4  QMAX	max. Emissionsrate
* R*4  RHO	Dichte
* R*4  RHO0	Normdichte
* R*4  TC	Char. Zeit in s
* R*4  GEFF	effektive Schwerebeschleunigung
* R*4  VNULL	Quellvolumen nach Kapitel 4.2
* R*4  VNUPU	Quellvolumenstrom
*
* === entry points ===
* SGERG
* SGPHAS        
* === aufgerufene Unterprogramme ===
* FRAME
* UZDIS
* WAIT
*-----------------------------------------------------------------------
* RHOA - Dichte der Luft = 1.2 kg/m**3
	parameter (rhoa=1.2)

	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)


	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL BATCH

*----------------------------------------------------------------------
	CALL FRAME ('Rechnung nach VDI 3783 Blatt 2')
*----------------------------------------------------------------------
* Bestimmung von RHO0 nach Tabelle 1, Seite 6

	IF (NFORM.LE.2) RHO0=RHONOR(NGAS)*273.15/(273.15+TPROZ)
	IF (NFORM.EQ.3) RHO0=RHONOR(NGAS)*273.15/(273.15+SIEDP(NGAS))
	IF (NFORM.EQ.4) RHO0=1.4

	IF (RHO0.LE.1.392) THEN
 91	FORMAT (/' !! Die anfngliche Gasdichte "RHO0" liegt unter',
     1		 ' 1.392 kg/m**3.')
		PRINT 91
		IERR=1
		GOTO 940
		END IF

*- effektive Fallbeschleunigung g' -
	GEFF=9.81*(RHO0-RHOA)/RHOA
* Dichte bei 15 Grad C und 1013 hPa
* da Quellstrke in g/s, RHO in g/m**3 ausdrcken - Faktor 1000.
	RHO=RHONOR(NGAS)*273.15/(273.15+15.) *1000.

*-----------------------------------------------------------------------
* eine Sttzstelle und TQ(1) maximal 1 s -- spontane Freisetzung
*-----------------------------------------------------------------------
	IF (NQ.EQ.1 .AND. TQ(1).LE.1.) THEN
		QTOTAL=Q(1)
		VNULL=QTOTAL/RHO
		IF (VNULL.LE.0.1) GOTO 900

		IFREI=1
		RLC(1)=VNULL**(1./3.)
		TC=SQRT(RLC(1)/GEFF)

		XK(1,1)=DXI(1,NGEB)*RLC(1)
		XK(2,1)=DXI(2,NGEB)*RLC(1)
		DTS(1)= DTI(1,NGEB)*TC
		DTS(2)= DTI(2,NGEB)*TC

		UC=SQRT(RLC(1)*GEFF)

		GOTO 700
		END IF

*-----------------------------------------------------------------------
* eine oder mehrere Sttzstellen -- kontinuierlicher oder variabler
* Emissionsverlauf
*-----------------------------------------------------------------------

* Berechnung der freigesetzten Masse und des grten Massenstroms (QMAX)
	QTOTAL=Q(1)*TQ(1)
	QMAX=Q(1)
	DO  200  K=2,NQ
	IF (Q(K).GT.QMAX)	QMAX=Q(K)
200	QTOTAL=QTOTAL+Q(K)*(TQ(K)-TQ(K-1))


* Entscheidung, ob kontinuierliche oder spontane Freisetzung
* in Abhngigkeit von der berechneten mittleren Entfernung des
* Kopplungspunktes

* spontane Freisetzung
	VNULL=QTOTAL/RHO

	RLC(1)=VNULL**(1./3.)
	TC=SQRT(RLC(1)/GEFF)

	XK(1,1)=DXI(1,NGEB)*RLC(1)
	XK(2,1)=DXI(2,NGEB)*RLC(1)
	DTS(1)= DTI(1,NGEB)*TC
	DTS(2)= DTI(2,NGEB)*TC

* kontinuierliche Freisetzung
	VNUPU=QMAX/RHO
	RLC(2)=((VNUPU**2)/GEFF)**(1./5.)

	XK(1,2)=DXC(1,NGEB)*RLC(2)
	XK(2,2)=DXC(2,NGEB)*RLC(2)

*-- kleinerer Wert bestimmt die Art der Freisetzung
	IF (XK(1,1) .GE. XK(1,2)) THEN

* Entscheidung fr kontinuierliche Freisetzung
		IF (VNUPU.LE.0.001)	GOTO 920
		IFREI=2
		UC=(VNUPU*GEFF**2)**(1./5.)
		ELSE

* Entscheidung fr spontane Freisetzung
		IF (VNULL.LE.0.1)	GOTO 900

		IFREI=1
		UC=SQRT(RLC(1)*GEFF)
		END IF

*-----------------------------------------------------------------------
* untere Znddistanz ermitteln
*-----------------------------------------------------------------------
700	CALL	UZDIS

*-----------------------------------------------------------------------
* Da der erste Aufpunkt in Blatt 1 mindestens 100m sein mu,
* wird hier der Quellversatz gegebenenfalls erhht.
*-----------------------------------------------------------------------
	XR(1)=4.*XK(1,IFREI)
	XR(2)=4.*XK(2,IFREI)
	IF (XR(1).LT.100.) XR(1)=100.
	IF (XR(2).LT.100.) XR(2)=100.

* Konzentration am Kopplungspunkt in [mg/m**3]
* g/m**3 -> mg/m**3 = Faktor 1000, davon  1% = Faktor 10
	CK=RHO*10.

* Punktquelle am Boden
	XQ=0.
	YQ=0.
	ZQ=0.
	HQ=Z0

	PRINT 11,	QTOTAL,STNAME(NGAS)
 11	FORMAT(/' Freigesetzt wurden insgesamt',G19.4,' g ',A24)

	IF (IFREI.EQ.1) THEN
		PRINT 12,	'spontan','Lci',RLC(1),UC
		ELSE
		PRINT 12,	'kontinuierlich','Lcc',RLC(2),UC
		END IF
 12	FORMAT(/' Berechnete Freisetzungsart:',T40,A/
     2		' Char. Lnge',T40,A3,'=',F6.1,' m'/
     3		' Char. Geschwindigkeit',T40,'Uc =',F6.1,' m/s')

	PRINT 13
 13	FORMAT(/t40,'mittlere       ungnstigste'/
     1		t40,'-- Ausbreitungssituation --')
	IF (UZG(NGAS).LT.0)	THEN
		PRINT 31
 31	FORMAT(/' Untere Znddistanz:',t43,'-',t60,'-')
		ELSE
		PRINT 32,UZD
 32	FORMAT(/' Untere Znddistanz:',t37,f8.1,' m',t54,f8.1,' m')
		END IF

	PRINT 14, XK(1,IFREI),XK(2,IFREI)
 14	FORMAT(' Kopplungspunkt:',t37,f8.1,' m',t54,f8.1,' m')
*-- bei spontaner Freisetzung ---
	IF (IFREI.EQ.1) PRINT 33,DTS
 33	FORMAT(' Zeit bis zur Kopplung:',t37,f8.1,' s',t54,f8.1,' s')

	PRINT 34, CK
 34	FORMAT(/' Gaskonzentration am Kopplungspunkt:',T40,E10.3,
     1		' mg/m**3'/)

	PRINT 15
 15	FORMAT(/' Die weitere Ausbreitung wird nach Blatt 1 berechnet.')
	IERR=0

	GOTO 990

*-----------------------------------------------------------------------
* Bei diesen Bedingungen ist mit Blatt 1 zu rechnen
*-----------------------------------------------------------------------
900	IERR=2
	PRINT 92
 92	FORMAT (/' !! Das anfngliche Quellvolumen V0 ist kleiner',
     1		' oder gleich  0.1 m**3.')
	GOTO 940

920	IERR=3
	PRINT 93
 93	FORMAT (/' !! Der Quellvolumenstrom "V0-PUNKT" betrgt weniger',
     1		' als 0.001 m**3/s.')

940	PRINT 94
 94	FORMAT (' !! Die Schwergaseffekte sind vernachlssigbar.'/
     1		' !! Die Rechnung erfolgt nach VDI 3783 Blatt 1.')

	IGAS=2
* bei Angabe einer Ausdehnung der Quelle von g/s auf g/s und Ausdehnung
* umrechnen
	LXQ=XQ.GE.1.
	LYQ=YQ.GE.1.
	LZQ=ZQ.GE.1.
	IQA=1
	A=1.
	IF (LXQ)	THEN
		IQA=IQA+1
		A=XQ
		END IF
	IF (LYQ)	THEN
		IQA=IQA+1
		A=A*YQ
		END IF
	IF (LZQ)	THEN
		IQA=IQA+1
		A=A*ZQ
		END IF
	IF (IQA.GT.1)	THEN
		PRINT 95,QUEDIM(IQA)
 95		FORMAT(/' Quellstrken von g/s auf ',A,' umgerechnet!')
		DO  950  IQ=1,NQ
		Q(IQ)=Q(IQ)/A
950		CONTINUE
		END IF

990	IF (.NOT.BATCH) CALL WAIT

	RETURN

*=======================================================================
	ENTRY SGERG
*=======================================================================
* Ausgabe der Rechnung nach Blatt 2 in eine Datei
*-----------------------------------------------------------------------
	IF (IERR.EQ.0)	THEN
*- Ergebnis der Schwergasausbreitung
	WRITE (33,80)
 80	FORMAT (/1X,37('*')/' * Ergebnis der Schwergasausbreitung *'/
     1		 1X,37('*'))
	WRITE (33,11)	QTOTAL,STNAME(NGAS)

	IF (IFREI.EQ.1) THEN
		WRITE (33,12)	'spontan','Lci',RLC(1),UC
		ELSE
		WRITE (33,12)	'kontinuierlich','Lcc',RLC(2),UC
		END IF

	WRITE (33,13)
	IF (UZG(NGAS).LT.0)	THEN
		WRITE (33,31)
		ELSE
		WRITE (33,32) UZD
		END IF

	WRITE (33,14) XK(1,IFREI),XK(2,IFREI)
*-- bei spontaner Freisetzung ---
	IF (IFREI.EQ.1) WRITE (33,33) DTS

	WRITE (33,17) XR(1)+XK(1,IFREI),XR(2)+XK(2,IFREI)
 17	FORMAT (/' Mindestwert fr 1. Aufpunkt:',
     1		t37,f8.1,' m',t54,f8.1,' m')

	WRITE (33,34) CK

	ELSE

*--- Behandlung nach Blatt 1 anzeigen
	IF (IERR.EQ.1)	WRITE (33,91)
	IF (IERR.EQ.2)	WRITE (33,92)
	IF (IERR.EQ.3)	WRITE (33,93)
	WRITE (33,94)

	END IF

	RETURN
	END

	BLOCKDATA
*---------------------------------------------------------------------
* Vorbesetzung von Variablen
*---------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	COMMON /CONST/	Z0I(5),PI,W2PI,DW2PI,DW2PI3,WPIH,W2

	DATA Z0I	/0.02,0.2,0.5,0.8,1.2/

	DATA QUEART	/'   Punkt',
     1			 '  Linien',
     2			 ' Flchen',
     3			 ' Volumen'/

	DATA QUEDIM	/'   g/s  ',
     1			 '  g/m/s ',
     2			 'g/m**2/s',
     3			 'g/m**3/s'/

	DATA JANEIN	/' ja ','nein'/

	DATA FORM	/
     1 'gasfrmig',
     2 'drucklos verflssigt',
     3 'unter Druck verflssigt',
     4 'unter Druck verflssigtes NH3 und sich hnlich verhaltende Gase'
     5			/

	END

	SUBROUTINE	SGUP1 (IND,CM,TMAX,*)
*-----------------------------------------------------------------------
* Berechnung des Konzentrationsverlaufs am Aufpunkt 5*DX
* und Interpolation auf den gewhlten Aufpunkt XA
* IND  - Index, 1 fr mittlere Ausbr., 2 fr ungnst. Ausbr.
*
* R*4  CM	Maximale Konzentration bei einem Konzentrationsverlauf
* R*4  FEX	Exponent fr die Interpolation
* I*4  I	Laufindex
* I*4  IND	1 - mittl., 2 - ungnst. Ausbreitungssituation
* I*4  INFH	Hilfvariable zum zwischenspeichern von INFO
* R*4  TMAX	Zeitpunkt zu dem CM berechnet wird
*
* === aufgerufene Unterprogramme ===
* MAXKON
* UP1
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX


* XA   - Aufpunkt im Absolutsystem - Quelle bei (0,0,0)
* XK   - Kopplungspunkt im Absolutsystem (XK,0,0), im Relativsystem
*	 fr Blatt 1 (0,0,0)
* XR   - 1. Aufpunkt fr Blatt 1 im Relativsystem
* XZ   - Aufpunkt im Relativsystem

	XZ=XA-XK(IND,IFREI)
* noch im Schwergasbereich ?
	IF (XZ.LT.0.)	THEN
	   IF (XA.LT.UZD(IND))	THEN
		PRINT 1
		IF (IAI.EQ.1)   WRITE (33,1)
  1	FORMAT (' Der Aufpunkt liegt noch im Zndbereich!')
		ELSE
		PRINT 2
		IF (IAI.EQ.1)   WRITE (33,2)
  2	FORMAT (' Der Aufpunkt liegt noch im Bereich mit ber 1% der',
     1		' Anfangskonzentration.')
		END IF
	   RETURN 1
	   END IF

* da in der Regel fr einen anderen als den gewnschten Aufpunkt
* gerechnet wird, Online-Anzeige abschalten
	INFH=INFO
	INFO=0

	IF (XZ.LT.XR(IND))	THEN
* Zwischen Kopplungspunkt und 1. Aufpunkt
		XA=XR(IND)
		YA=0.
		ZA=0.
		CALL UP1
		IF (NZI.EQ.0. OR. NZI.EQ.2)  CALL MAXKON (CM,TMAX)

*-- Interpolation fr Aufpunkte kleiner als XR --
		CCSUM=0.
		FEX=ALOG10((XZ+XK(IND,IFREI))/XK(IND,IFREI))/
     1		    ALOG10((XA+XK(IND,IFREI))/XK(IND,IFREI))
		DO  200  I=1,NNN
		CC(I)=CK*(CC(I)/CK)**FEX
		CCSUM=CCSUM+CC(I)
		TIME(I)=DTS(IND)+TIME(I)*XZ/XA
200		CONTINUE

		CM=CK*(CM/CK)**FEX
		TMAX=DTS(IND)+TMAX*XZ/XA
		IF (KCMAX.EQ.IK)	THEN
			TCMAX=TMAX
* wenn Interpolation notwendig, dann ist ZA=0, d.h. Aufpunkt und
* Quellhhe sind identisch - der ungnstigste Fall ist der stabile.
* Indifferente und labile Situation brauchen nicht untersucht werden.
			CCMAX=CM
			Z9(2)=.TRUE.
			Z9(3)=.TRUE.
			END IF

		ELSE

*-- Interpolation fr Aufpunkte grer als XR --
* Zeitoffset addieren
		XA=XZ
		CALL UP1
		IF (NZI.EQ.0. OR. NZI.EQ.2)  CALL MAXKON (CM,TMAX)

		DO  300  I=1,NNN
300		TIME(I)=DTS(IND)+TIME(I)

		TMAX=DTS(IND)+TMAX
		IF (KCMAX.EQ.IK)	TCMAX=TMAX
		END IF

* XA zurcksetzen
	XA=XZ+XK(IND,IFREI)

	INFO=INFH

* versptete Ausgabe des Verlaufs
	IF (INFO.GT.0)	THEN
		PRINT 4
 4	FORMAT(' Sttzstelle    Zeit (s)   Konzentration (mg/m**3)')
		PRINT 5,(I,TIME(I),CC(I),I=1,NNN)
 5	FORMAT(I8,F15.1,G16.3)
		END IF

	RETURN
	END

	SUBROUTINE	PARAUS (Version)
*-----------------------------------------------------------------------
* Ausgabe der eingegebenen bzw. eingelesenen Parameter in die
* Ergebnisdatei bzw. auf den Drucker.
*-----------------------------------------------------------------------
* I*4  I	Laufindex (1...NQ)
* I*2  ID	Tag (1...31)		)
* I*2  IM	Monat (1...12)		) Systemzeit
* I*2  IY	Jahr (19xx)		)
*
* === aufgerufene Unterprogramme ===
* GETDAT (MS-FORTRAN-Function, liefert Systemdatum)
*	 Analogon in VAX-FORTRAN: idate (...)
* SGERG         
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)


	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO


	INTEGER*2	IY,IM,ID
$IF DEFINED (MSOFT)
$ELSE
*LAHEY
	CHARACTER	DATUM*8
$ENDIF

* XR	 - Mindestwert fr 1. Aufpunkt in Blatt 1

*----------------------------------------------------------------------
* Ausgabe der Eingangsparameter
*----------------------------------------------------------------------
$IF DEFINED (MSOFT)
* MicroSoft-Function um das System-Datum zu ermitteln
* (mu bei anderen Compilern in der Regel abgendert werden)
	CALL	GETDAT (IY,IM,ID)
$ELSE
* fr VMS-Fortran
*VAX	CALL	IDATE (IM,ID,IY)
*VAX	IY=1900+IY

* fr LAHEY-Fortran
	CALL	DATE (DATUM)
	READ (DATUM,'(I2,1X,I2,1X,I2)') IM,ID,IY
	IY=1900+IY
$ENDIF

	WRITE (33,1) Version,ID,IM,IY
   1	FORMAT('== STOER V',F4.2,' == ',2(I2.2,'.'),I4,1X,51('='))

	WRITE (33,18)  TITEL
 18	FORMAT (/1H ,A//1H ,22('*')/' *  Eingabeparameter  *'/
     1	1H ,22('*')/)

*----------------------------------------------------------------------
* Schwergasparameter
*----------------------------------------------------------------------
	IF (IGAS.EQ.1 .OR. IERR.GT.0)	THEN

	  WRITE (33,71)  STNAME(NGAS)
 71	  FORMAT (' Gasart:',T38,A)

*- bei Sondergas physikalische Kenngren ausgeben
	  IF (NGAS.EQ.maxgas)
     1		 WRITE (33,72) SIEDP(NGAS),RHONOR(NGAS),UZG(NGAS)
 72	  FORMAT (' Siedepunkt:',T38,F6.1,' Grad C'/
     1		  ' Normdichte:',T38,F6.2,' kg/m**3'/
     2		  ' Untere Zndgrenze:',T38,F6.1,' Vol%')

	  IF (NFORM.LT.4) THEN
	    WRITE (33,73)  FORM(NFORM)
	    ELSE
	    WRITE (33,73)  FORM(NFORM)(1:30),FORM(NFORM)(31:64)
	    END IF

 73	  FORMAT (' Freisetzungsform:',T38,A:/T38,A)
 75	  FORMAT (' Prozetemperatur:',T38,F6.1,' Grad C'/)
	  IF (NFORM.LE.2) WRITE (33,75)  TPROZ
	  END IF

*----------------------------------------------------------------------
* Standortparameter
*----------------------------------------------------------------------
399	WRITE (33,40)
	IF (IGAS.EQ.1)	WRITE (33,74) GEBIET(NGEB)
	WRITE (33,404) IZ0,Z0
	WRITE (33,401) HM
 40	FORMAT (' Standortparameter:')
 74	FORMAT ('   Ausbreitungsgebiet:',T38,A)
404	FORMAT ('   Rauhigkeitsklasse',I5,T38,'Z0 =',F6.2,2X,'m')
401	FORMAT ('   mittlere Bebauungshhe',T42,F6.1,2X,'m')

*----------------------------------------------------------------------
* Quellparameter
*----------------------------------------------------------------------
	WRITE (33,17)  QUEART(IQA)
	WRITE (33,402) XQ,YQ,ZQ
	WRITE (33,400) HQ
	WRITE (33,403) TQ(NQ)
	IF (NQ.EQ.1)	THEN
		IF (IGAS.EQ.1)	THEN
			WRITE (33,77)  Q(1)
			ELSE
			WRITE (33,408) Q(1),QUEDIM(IQA)
			END IF
		ELSE
		WRITE (33,76)
		WRITE (33,78) QUEDIM(IQA)
		WRITE (33,79) (I,TQ(I),Q(I),I=1,NQ)
		END IF

*----------------------------------------------------------------------
* Berechnung der freigesetzten Masse in g
*----------------------------------------------------------------------
	IF (IGAS.GT.1)	THEN
		QTOTAL=Q(1)*TQ(1)
		DO  200  K=2,NQ
200		QTOTAL=QTOTAL+Q(K)*(TQ(K)-TQ(K-1))
		QTOTAL=QTOTAL*AMAX1(1.,XQ)*AMAX1(1.,YQ)*AMAX1(1.,ZQ)
		WRITE (33,81) QTOTAL
		END IF

 17	FORMAT (/' Quellparameter der',A,'quelle:')
402	FORMAT ('   Quellabmessungen',	T38,'XQ =',F6.1,2X,'m'/
     1					T38,'YQ =',F6.1,2X,'m'/
     2					T38,'ZQ =',F6.1,2X,'m')
400	FORMAT ('   Quellhhe',T42,F6.1,2X,'m'/)
403	FORMAT ('   Emissionsdauer',T42,F6.0,2X,'s')
408	FORMAT ('   Quellstrke',T31,G15.4,1X,A)
 76	FORMAT (' Emissionsverlauf:')
 77	FORMAT ('   Freigesetzte Masse o. Lachenanteil:',T39,E9.3,
     1		'  g/s')						!V2.12
 78	FORMAT (T10,' Sttz-        Zeit nach         Quellstrke'/
     1		T10,' stelle     Emissionsbeginn'/
     2		T10,'                  (s)             (',A,')'/)
 79	FORMAT (T10,I4,11X,F7.1,11X,E9.3)
 81	FORMAT (/'   Freigesetzte Masse:',T39,E9.3,'  g')

*----------------------------------------------------------------------
* Ergebnisse der Schwergasrechnung ausgeben
*----------------------------------------------------------------------
	IF (IGAS.EQ.1 .OR. IERR.GT.0)	CALL SGERG
	IF (NUR2.EQ.1)	RETURN

* NUE=2 - keine berhhung
	IF (NUE.EQ.2)	GOTO 22

	IF (IW.EQ.1)	THEN
413	FORMAT ('   Wrmeemission',T31,G15.3,1X,'MW')
		IF (NQ.EQ.1)	THEN
			WRITE (33,413) QH(1)
			ELSE
			WRITE (33,567)
567	FORMAT ('   Sttzstelle  Wrmeemission in MW')
			WRITE (33,568) (I,QH(I),I=1,NQ)
568	FORMAT (7X,I3,8X,G15.3)
			END IF
		GOTO 22
		END IF

	IF (IQ.EQ.1)	THEN
		WRITE (33,405)
		WRITE (33,26) (RO(I),R(I),QH(I),I=1,NQ)
405	FORMAT ('   Schadstoffdichte   Volumenstrom   Wrmeemission'/
     1		'      (kg/m**3)         (m**3/s)          (MW)')
 26	FORMAT (3X,E11.3,5X,E12.3,3X,F12.2)

		ELSE

		WRITE (33,27)
		WRITE (33,26) (TT(I),R(I),QH(I),I=1,NQ)
 27	FORMAT('   Schadstofftemp.     Volumenstrom   Wrmeemission'/
     1		'      (Grad C)          (m**3/s)          (MW)')
		END IF

*----------------------------------------------------------------------
* Was wird untersucht
*----------------------------------------------------------------------
 32	FORMAT(' *  Berechnung ',A,'  *')
 33	FORMAT(1X,44A1)
 22 	WRITE (33,*)
	IF (NZI.EQ.1)	THEN
		WRITE (33,33) ('*',I=1,26)
		WRITE (33,32) 'der Dosis'
		WRITE (33,33) ('*',I=1,26)
		ELSE IF (NZI.EQ.2) THEN
		WRITE (33,33) ('*',I=1,41)
		WRITE (33,32) 'der Maximalkonzentration'
		WRITE (33,33) ('*',I=1,41)
		ELSE IF (NZI.EQ.3) THEN
		WRITE (33,33) ('*',I=1,44)
		WRITE (33,32) 'des Konzentrationsverlaufes'
		WRITE (33,33) ('*',I=1,44)
		ELSE IF (NZI.EQ.0) THEN
		WRITE (33,33) ('*',I=1,38)
		WRITE (33,32) 'aller Immissionsdaten'
		WRITE (33,33) ('*',I=1,38)
		END IF
	RETURN
	END

	SUBROUTINE	FOPEN (DATEI,OPN33)
*-----------------------------------------------------------------------
* ffnen der Ausgabedatei auf FORTRAN-Unit 33
*-----------------------------------------------------------------------
* CHAR DATEI	Dateiname (kann auch PRN sein)
* CHAR DATEJ	Dateiname einer evtl. bereits geffneten Datei
* L*4  OPN33	Flag, ob Datei bereits geffnet ist
*-----------------------------------------------------------------------
	CHARACTER DATEI*30,DATEJ*30
	LOGICAL OPN33
	DATA DATEJ /'PRN'/

	IF (OPN33 .AND. DATEI.NE.DATEJ)	THEN
		CLOSE (UNIT=33)
		OPN33=.FALSE.
		END IF
	IF (.NOT.OPN33)		THEN
		OPEN (UNIT=33,FILE=DATEI,STATUS='UNKNOWN')
		OPN33=.TRUE.
		DATEJ=DATEI
		END IF
	RETURN
	END

	SUBROUTINE	AUSWER ()
*-----------------------------------------------------------------------
* Steuerung der Berechnung der Konzentration fr eine mittlere
* Ausbreitungssituation und fr die ungnstigste Ausbreitungssituation.
*-----------------------------------------------------------------------
* R*4  CM	Maximalkonzentration fr eine bestimmte Ausbreitungs-
* 		situation
* I*4  I	Laufindex
* I*4  II	Laufindex
* I*4  IKK	Laufindex ber die Ausbreitungsklassen
* R*4  TMAX	Zeitpunkt zu dem bei einer Ausbreitungssituation die
*		Maximalkonz. auftrat
*
* === Felder ===
* R*4  SK(nemi,3)
*		Schadstoffkonzentration in Abhngigkeit der Zeit
*		(1.Index) und der Stabilitt (2.Index)
* R*4  SSK(nemi,3)
*		wie SSK, jedoch fr vorangegangene Geschwindigkeitsstufe
*
* CHAR TSCHI(3) Textkennung der Schichtung
*
* === aufgerufene Unterprogramme ===
* DOSIS
* MAXKON
* SGUP1
* UP1
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX

	DIMENSION	SK(nimi,3),SSK(nimi,3)
	CHARACTER	TSCHI(3)*12

	DATA TSCHI/	'stabil      ',
     1			'indifferent ',
     1			'labil       '/

	PRINT '(1H )'
* Dauer der einzelnen Emissionsabschnitte
	TD(1)=TQ(1)
	DO 100 I=2,NQ
100	TD(I)=TQ(I)-TQ(I-1)

*----------------------------------------------------------------------
* mittlere Ausbreitungssituation - keine Inversion
*----------------------------------------------------------------------
	HI=0.
	U=UM
	IU=0
* soll nur eine Ausbreitungssituation berechnet werden, so kann dies
* durch Vorgabe von MW geschehen,
* ist MW neg. oder Null, dann ohne Inversion rechnen, sonst mit.
	INVRS=MW.GT.0
	IF (MW.EQ.0)	THEN
		IK=2
				PRINT 42,	'mittlere'
		IF (IAI.EQ.1)	WRITE(33,42)	'mittlere'
		ELSE
		IK=IABS(MW)
				PRINT 42,	'vorgegebene'
		IF (IAI.EQ.1)	WRITE(33,42)	'vorgegebene'
		END IF
 42	FORMAT (/1X,10('-'),1X,A,' Ausbreitungssituation ',10('-'))

 57	FORMAT(' Ausbreitungsklasse',I4,5X,'Schichtung:',3X,A)
577	FORMAT(' Windgeschwindigkeit in Anemometerhhe',T43,F6.1,
     1	' m/s')
578	FORMAT(' Transportgeschwindigkeit',T43,F6.1,' m/s')
579	FORMAT(' mit Inversion in einer Hhe von',T43,F6.1,' m')
580	FORMAT(' keine Inversion')
581	FORMAT(' effektive Quellhhe',T43,F6.1,' m')

	PRINT 57,  IK,TSCHI(IK)
	PRINT 577, U

*----------------------------------------------------------------------
* Berechnung des Konzentrationsverlaufs
*----------------------------------------------------------------------
	IF (IGAS.EQ.1)	THEN
*-- Im Schwergasfall --
		CALL	SGUP1 (1,CM,TMAX,*900)
		ELSE
*-- dichteneutrale und heie Gase --
		CALL	UP1
		END IF
*---------------------------------------------------------------------
* Ausgabe der meteorologischen Parameter in die Ausgabedatei
*----------------------------------------------------------------------
	IF (IAI.EQ.1)	THEN
		WRITE (33,57) IK,TSCHI(IK)
		IF (INVRS)	THEN
			WRITE (33,579) HIXA
			ELSE
			WRITE (33,580)
			END IF
		WRITE (33,577) U
		WRITE (33,578) UUXA
		IF (NUE.EQ.1)	WRITE (33,581) HXA
		END IF

*----------------------------------------------------------------------
* wenn keine Immission berechnet, vereinfacht sich die Ausgabe
*----------------------------------------------------------------------
	IF (CCSUM.EQ.0.)	THEN
				PRINT 444
		IF (IAI.EQ.1)	WRITE(33,444)
* Fehler bei Version 1.00, Initialisierung bei IU=0 in MAXKON und DOSIS
* wurde im Fall CCSUM=0. nicht durchgefhrt.
		IF (IGAS.GT.1)	CALL MAXKON (CM,TMAX)
		CALL DOSIS
		GOTO 46
		END IF

*----------------------------------------------------------------------
* Verzweigen (Dosis - Max.Konz. - Konz.verlauf)
*----------------------------------------------------------------------
	GOTO (37,38,39,40),NZI

*----------------------------------------------------------------------
* Konzentrationsverlauf ausgeben
*----------------------------------------------------------------------
 39	IF (INFO.EQ.0)	THEN
			PRINT 409
			PRINT 58, (TIME(I),CC(I),I=1,NNN)
			END IF
	IF (IAI.EQ.1)	THEN
			WRITE(33,409)
			WRITE(33,58) (TIME(I),CC(I),I=1,NNN)
			END IF
	IF (NZI.GT.0)	GOTO 46

*----------------------------------------------------------------------
* hchste Konzentration fr diese Ausbreitungssituation berechnen
* und Eintrittszeitpunkt bestimmen
* (bei schwerem Gas von SGUP1 gesteuert)
*----------------------------------------------------------------------
 38	IF (IGAS.GT.1)	CALL	MAXKON (CM,TMAX)
* Werte ausgeben
 43	FORMAT(/' hchste Konzentration',T26,G15.4,' mg/m**3'/
     1	18X,'nach',T35,F6.0,' s')
			PRINT 43,	CM,TMAX
	IF (IAI.EQ.1)	WRITE(33,43)	CM,TMAX
	IF (NZI.GT.0)	GOTO 46

*----------------------------------------------------------------------
* Dosis berechnen (Integral ber die Zeit)
*----------------------------------------------------------------------
 37	CALL	DOSIS
	GOTO 46

*----------------------------------------------------------------------
* nur ein Zeitpunkt zu dem die Konzentration berechnet werden sollte
*----------------------------------------------------------------------
 40	IF (IAI.EQ.1)	WRITE (33,41) TIME(1),CC(1)
 41	FORMAT(' am Aufpunkt nach',F8.1,' s',G15.4,' mg/m**3')

*----------------------------------------------------------------------
* war nur vorgegebene Ausbreitungssituation gewnscht, dann Ende
*----------------------------------------------------------------------
 46	IF (IAI.EQ.1)	WRITE (33,59)
 59	FORMAT(/1X,52('-'))
	IF (MW.NE.0)	RETURN

*----------------------------------------------------------------------
*  ungnstigste Ausbreitungssituation *
*----------------------------------------------------------------------
	IU=0
	CCMAX=0.
	CDMAX=0.
	DO 47 IK=1,3
	Z9(IK)=.FALSE.
	DO 47 I=1,NNN
	SSK(I,IK)=0.
 47	SK(I,IK)=0.
	INVRS=.TRUE.

* Geschwindigkeit bei berhhungsbercksichtigung weiter erhhen bis
* alle Ausbreitungsklassen besetzt
 69	IU=IU+1

* nach DILGER/NESTER max. Geschwindigkeit in den Fllen
* Stabil	-  6 m/s
* Indifferent	- 10 m/s
* Labil		-  7 m/s
	IF (IU.GT.10)	GOTO 700
	Z9(1)=Z9(1) .OR. IU.GT.6
	Z9(3)=Z9(3) .OR. IU.GT.7

*----------------------------------------------------------------------
* Schleife ber Ausbreitungsklassen
*----------------------------------------------------------------------
	DO 49 IK=1,3
* schon Konzentration vorhanden oder IU > Grenzgeschwindigkeit,
* dann diese Ausbreitungsklasse nicht mehr berechnen
	IF (Z9(IK))	GOTO 49
	U=IU
		PRINT 59
		PRINT 57,  IK,TSCHI(IK)
		PRINT 577, U

*----------------------------------------------------------------------
* Berechnung des Konzentrationsverlaufs
*----------------------------------------------------------------------
	IF (IGAS.EQ.1)	THEN
*-- Im Schwergasfall --
		CALL	SGUP1 (2,CM,TMAX,*900)
		ELSE
*-- dichteneutrale und heie Gase --
		CALL	UP1
		END IF

*----------------------------------------------------------------------
* wieder verzweigen (Dosis - Max.Konz. - Konz.verlauf)
*----------------------------------------------------------------------
	GOTO (50,51,52,53) ,NZI

*----------------------------------------------------------------------
* Konzentrationsverlauf ausgeben
*----------------------------------------------------------------------
 52	IF (INFO.EQ.0)	THEN
		PRINT 409
		PRINT 58, (TIME(I),CC(I),I=1,NNN)
		END IF
	IF (IAI.EQ.1)	THEN
* Ausgabe der meteorologischen Parameter in die Ausgabedatei
		WRITE (33,59)
		WRITE (33,57)  IK,TSCHI(IK)
		WRITE (33,579) HIXA
		IF (NUE.EQ.1)	THEN
			WRITE (33,581) HXA
			WRITE (33,577) U
			END IF
		WRITE (33,578) UUXA

* wenn keine Immission berechnet wurde
		IF (CCSUM.EQ.0.)	THEN
			WRITE(33,444)
			GOTO 49
			END IF

		WRITE(33,409)
		WRITE(33,58) (TIME(I),CC(I),I=1,NNN)
		END IF

409	FORMAT (/'    Zeit (s)      Konzentration (mg/m**3)')
 58	FORMAT (1H ,F10.1,2X,G20.3)

* mit berhhung: Verlauf fr jede Klasse speichern, damit nacher
* abgebrochen werden kann, wenn bei Steigerung der Geschwindigkeit
* die Konzentration zurckgeht.
	IF (NUE.EQ.1)	THEN
		DO 60 I=1,NNN
 60		SK(I,IK)=CC(I)
		END IF
	IF (NZI.GT.0)	GOTO 49

*----------------------------------------------------------------------
* hchste Konzentration fr diese Ausbreitungssituation bestimmen
*----------------------------------------------------------------------
 51	IF (IGAS.GT.1)	CALL	MAXKON (CM,TMAX)
* Werte ausgeben
	IF (CM.EQ.0.)	THEN
		PRINT 444
		ELSE
		PRINT 43,CM,TMAX
		IF (IAI.EQ.1 .AND. NZI.EQ.0) WRITE (33,43) CM,TMAX
		END IF
	IF (NZI.GT.0)	GOTO 49

*----------------------------------------------------------------------
* Dosis berechnen und Feststellen ob Maximum
*----------------------------------------------------------------------
 50	IF (CCSUM.GT.0.)	CALL	DOSIS
	GOTO 49

*----------------------------------------------------------------------
* nur ein Zeitpunkt zu dem die Konzentration berechnet werden sollte
*----------------------------------------------------------------------
 53	IF (IAI.EQ.1)	WRITE (33,41) TIME(1),CC(1)

 49	CONTINUE

	IF (NUE.EQ.2)	GOTO 700
*----------------------------------------------------------------------
* Auswahl der ungnstigsten Windgeschwindigkeit fr jede Stabilitt
* nur bei Bercksichtigung der berhhung und der Untersuchung der
* Konzentrationsverteilung.
*----------------------------------------------------------------------
* Ist Konzentrationsverlauf bei mind. einer der Stabilitten ansteigend
	IF (NZI.GE.3 .OR. NZI.EQ.0)	THEN
		DO 800 IKK=1,3
* beim ersten Durchlauf (IU=1) SSK erst mal besetzen
		IF (IU.EQ.1)		GOTO 720
* diese Stabilittsklasse schon abgehakt?
		IF (Z9(IKK))		GOTO 800

		DO 710 II=1,NNN
* Overflow vermeiden
		IF (SSK(II,IKK).LT.1.E-30)	GOTO 710
* eine der Konzentrationen um mehr als 10% grer als die bei der
* vorausgegangenen Geschwindigkeitsstufe, dann weiter
		IF (SK(II,IKK)/SSK(II,IKK).GT.1.1)	GOTO 720
* wenn nicht grer als die vorangegangenen, aber grer als 0 dann
* Endeflag setzen
		IF (SK(II,IKK).GT.0.)	Z9(IKK)=.TRUE.
710		CONTINUE
		IF (Z9(IKK))		GOTO 800
* Umspeichern
720		Z9(IKK)=.FALSE.
		DO 740 II=1,NNN
740		SSK(II,IKK)=SK(II,IKK)

800		CONTINUE
* wenn noch nicht alle Ausbreitungsklassen besetzt, dann weiter
		IF (.NOT.(Z9(1).AND.Z9(2).AND.Z9(3)))	GOTO 69
		END IF
* Geschwindigkeit braucht nicht weiter erhht zu werden, wenn Dosis
* oder Maximalkonz. abnehmen oder 10m/s erreicht sind.
	IF (NZI.EQ.2 .AND. CINC)			GOTO 69
	IF (NZI.EQ.1 .AND. DINC)			GOTO 69
	IF (NZI.EQ.0 .AND. (CINC.AND.DINC))		GOTO 69
*----------------------------------------------------------------------
700	IF (NZI.GE.3)	GOTO 900

*----------------------------------------------------------------------
* Ausgabe der Maximalkonzentration bzw. -Dosis bei den ungnstigsten
* Bedingungen
*----------------------------------------------------------------------
	IF (AMAX1(CCMAX,CDMAX).EQ.0.)	THEN
* Keine Immission an diesem Aufpunkt
444	FORMAT(/' bei diesen Bedingungen am Aufpunkt keine Immission!')
				PRINT 444
		IF (IAI.EQ.1)	WRITE(33,444)
		GOTO 900
		END IF

	PRINT 433
433	FORMAT (/1X,8('-'),' ungnstigste Ausbreitungssituation ',
     1		8('-'))

* verzweigen (Dosis - Max.Konz.)
	IF (NZI.LE.1)	THEN
* Maximaldosis ausgeben
			PRINT  57,	KDMAX,TSCHI(KDMAX)
			PRINT 579,	HDMAX
			PRINT 577,	FLOAT(IDMAX)
			PRINT 578,	UDMAX
			PRINT  64,	CDMAX
			PRINT  59
		IF (IAI.EQ.1)	THEN
			WRITE(33,433)
			WRITE(33,57)	KDMAX,TSCHI(KDMAX)
			WRITE(33,579)	HDMAX
			IF (NUE.EQ.1)	WRITE(33,577) FLOAT(IDMAX)
			WRITE(33,578)	UDMAX
			WRITE(33,64)	CDMAX
			IF (NZI.EQ.0)	THEN
				WRITE (33,*)
				WRITE (33,59)
				END IF
			END IF
 64	FORMAT(/' Maximaldosis',T26,G15.4,' mg*s/m**3')
		END IF

	IF (NZI.NE.1)	THEN
* Maximalkonzentration ausgeben
			PRINT  57,	KCMAX,TSCHI(KCMAX)
			PRINT 579,	HCMAX
			PRINT 577,	FLOAT(ICMAX)
			PRINT 578,	UCMAX
			PRINT  44,	CCMAX,TCMAX
		IF (IAI.EQ.1)	THEN
			WRITE(33,433)
			WRITE(33,57)	KCMAX,TSCHI(KCMAX)
			WRITE(33,579)	HCMAX
			IF (NUE.EQ.1)	WRITE(33,577) FLOAT(ICMAX)
			WRITE(33,578)	UCMAX
			WRITE(33,44)	CCMAX,TCMAX
 44	FORMAT(/' Maximalkonzentration',T26,G15.4,' mg/m**3'/
     1	17X,'nach',T35,F6.0,' s')
			END IF
		END IF
*----------------------------------------------------------------------
900	IF (IAI.EQ.1)	WRITE (33,59)
	RETURN
	END

	SUBROUTINE	UP1
*-----------------------------------------------------------------------
* Unterprogramm zur Bestimmung der Ankunftzeit der Vorder- und Rckkante
* der Abgaswolke und der maximalen berhhung.
* Die Beaufschlagungszeit wird unter Bercksichtigung der Diffussion in
* x-Richtung bestimmt, sofern die Immissionssttzstellen nicht
* vorgegeben waren.
* Fr diese Sttzstellen wird dann die Konzentration ermittelt.
*-----------------------------------------------------------------------
* I*4  I	Laufindex
* I*4  IS	Laufindex
* I*4  IT	Laufindex
* R*4  HD	maximale berhhung in Abhngigkeit von der Wrmeemission
* R*4  S1	Teilergebnisse bei der Konzentrationsberechnung
* R*4  S9	Hilfsvariable zur Bestimmung der Beaufschlagungszeit
* R*4  SI	Hilfsvariable zur Bestimmung der Beaufschlagungszeit
* 		(+1sec bzw. -1sec)
* R*4  SM	Hilfsvariable zur Bestimmung der Beaufschlagungszeit
* R*4  T2	...
* R*4  T8	...
* R*4  T9	...
* R*4  TMAX	Ankunftzeit der Rckseite der Schadstoffwolke am Aufpunkt
* 		ohne Bercksichtigung der Diffusion in x-Richtung
* R*4  TMIN	Ankunftzeit der Vorderseite der Schadstoffwolke am Aufpunkt
* 		ohne Bercksichtigung der Diffusion in x-Richtung
* R*4  TZ	Ankunftszeit der Vorder- bzw. Rckseite der Schadstoffwolken
* 		die durch die einzelnen Emissionsabschnitte erzeugt werden
*
* === Felder ===
* R*4  TM(3)	Beginn TM(1) und Ende TM(3) der Beaufschlagungszeit
* 		in Sekunden nach Emissionsbeginn
*
* === aufgerufene Unterprogramme ===
* CUP
* DHUU
* EMISSI
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX

	DIMENSION	TM(3)

*----------------------------------------------------------------------
* Bestimmung der Beaufschlagungszeit
*----------------------------------------------------------------------
	UU=U
	HD=HQ
* berhhung bercksichtigen ?
	IF (NUE.EQ.1)	THEN
* ja -
		TMIN=1.E38
		TMAX=0.
		TU=XA
		DO 100 IT=1,NQ

		CALL DHUU (1,IT)

* Inversionshhe = maximale eff. Quellhhe bei Abschnitten
* unterschiedlicher Wrmeemission
		IF (HD.LT.H)	HD=H
		T=XA/UU
		TZ=T+TQ(IT)
		IF (IT.GT.1)	T=T+TQ(IT-1)
		IF (T .LT.TMIN)	TMIN=T
		IF (TZ.GT.TMAX)	TMAX=TZ
100		CONTINUE

		TMAX=TMAX+XQ/UU

	ELSE	IF (IU.NE.0)	THEN
* nein - also keine berhhung
		TMIN=XA/U
		TMAX=TMIN+TQ(NQ)

	ELSE
* bei mittlerer Ausbreitungssituation TMIN und TMAX mit gemittelter
* Geschwindigkeit UU
		DH=0.

		CALL DHUU (3,IT)

		TMIN=XA/UU
		TMAX=TMIN+TQ(NQ)+XQ/UU
	END IF

* Hhe der Inversion (Maximum aus:
* Quellhhe HQ, max.eff.Quellhhe HD, 20.m , der Bebauungshhe HM und
* der Aufpunktshhe ZA)
	IF (INVRS)	THEN
		HI0=AMAX1(HQ,20.,HM,ZA)
		HI =AMAX1(HD,HI0)
		END IF
* Inversionshhe, eff. Quellhhe und mittl. Geschwindigkeit am
* Aufpunkt festhalten
	HIXA=HI
	UUXA=UU
	HXA =H
* diese Gren auf Bildschirm ausgeben
	IF (INFO.GT.0)	THEN
		PRINT 1,UU
		IF (NUE.EQ.1) PRINT 6,H
  1	FORMAT(' Transportgeschwindigkeit:',T40,F9.1,' m/s')
  6	FORMAT(' effektive Quellhhe:',T40,F9.1,' m')
		IF (HI.GT.0.)	THEN
			PRINT 2,HI
  2	FORMAT( ' Hhe der Inversion:',T40,F9.1,' m')
			ELSE
			PRINT 11
 11	FORMAT( ' keine Inversion')
			END IF
		END IF

* --- UP2 ---
* bei vorgegebenen Immissionssttzstellen braucht keine
* Beaufschlagungszeit berechnet zu werden.
	NNN=NTM
	IF (NZI.EQ.4)	GOTO 450
	IF (JST.GT.0)	THEN
  7	FORMAT(' Zeiten der Immissionssttzstellen vorgegeben')
		IF (INFO.GT.0)	PRINT 7
		IF (IAI.EQ.1 .AND. IU.EQ.0)	WRITE (33,7)
		GOTO 450
		END IF
	IF (INFO.GT.0)	PRINT 12
 12	FORMAT(' Bestimmung der Beaufschlagungszeit')

* hier wird die Beaufschlagungszeit unter Bercksichtigung der
* Diffussion in x-Richtung bestimmt
	DO  290  IS=-1,1,2
	SI=FLOAT(IS)
	IF (IS.LT.0)	THEN
		T=TMIN
		ELSE
		T=TMAX
		END IF

	T8=T
	T9=T
	T2=0.
	SM=0.
* Konz. zur Zeit TMIN bzw. TMAX bestimmen
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.EQ.0.)	GOTO 280
	S9=SS
	T=T+SI
* Konz. zur Zeit TMIN-1sec bzw. TMAX+1sec bestimmen
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.LT.S9)	GOTO 202
* Maximum hinter TMAX oder vor TMIN

215	S1=SS
	T2=T+IS*SY/UU
	T=T2
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.GE.S1)	GOTO 215

207	T=(T2+T9)/2.
C* Auflsung auf 1s wrde gengen AMAX1(1.,T8/10)
	IF (ABS(T2-T9) .LT. AMIN1(T8/10.,30.))	GOTO 202
	IF (ABS(T-T2)  .LT. 1.)			GOTO 202
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.EQ.0.)	THEN
		T2=T
		GOTO 207
		END IF

	IF (ABS(SM-SS)/SS .LT. 0.01)	GOTO 202
	SM=SS
	T=T+SI
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.LT.SM)	THEN
		T2=T
		ELSE
		T9=T
		END IF
	GOTO 207

202	IF (NZI.EQ.2)	THEN
* bei Maximalkonzentrationen die Beaufschlagungszeiten auf der sicheren
* Seite nehmen
		IF (T2.GT.0.)	T=T2
		GOTO 280
		END IF
* wenn Dosis oder Konzentrationsverlauf, dann
	T9=T
	S9=SS/10.
210	T=T+IS*SY/UU

		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.GT.S9)	GOTO 210
	T2=T
212	T=(T2+T9)/2.
	IF (ABS(T2-T9) .LT. AMIN1(T8/10.,30.))	GOTO 280
		CALL EMISSI
	IF (INFO.GT.1)	call cup (0)
	IF (SS.LT.S9)	THEN
		T2=T
		ELSE
		T9=T
		END IF
	GOTO 212

* Beaufschlagungszeit ausgeben
* Zeiten auf ganze Sekunden runden
280	IF (IS.LT.0)	THEN
		T=AINT(T)
		IF (T.LT.0.)	T=0.
		IF (INFO.GT.0)	PRINT 3,'Beginn:',T
		TM(1)=T
		ELSE
		T=ANINT(T+1.)
		IF (INFO.GT.0)	PRINT 3,'Ende:  ',T
 3		FORMAT(1X,A,F8.1,' s')
		TM(3)=T
		END IF
290	CONTINUE

* --- UP2_ENDE ---
* Bestimmung des Zeitinkrements bei NNN Immissionssttzstellen
	TTD=(TM(3)-TM(1))/FLOAT(NNN-1)
* TTD >1s  dann OK, sonst Anzahl reduzieren
	IF (TTD.LT.1.)			THEN
		NNN=IFIX(TM(3)-TM(1))+1
		IF (NNN.GT.2)			THEN
			TTD=(TM(3)-TM(1))/FLOAT(NNN-1)
			ELSE
			TM(1)=(TM(1)+TM(3))/2.
			NNN=1
			TTD=(TM(3)-TM(1))/2.
			END IF
		END IF
* auf Sekunden runden
	TTD=ANINT(TTD)

	DO  400 I=1,NNN
400	TIME(I)=TM(1)+(I-1)*TTD

* Berechnung und Bildschirmausgabe des Immissionsverlaufs

450	CCSUM=0.
	IF (INFO.GT.0)	PRINT 4
 4	FORMAT(' Sttzstelle    Zeit (s)   Konzentration (mg/m**3)')
	DO 500 I=1,NNN
	T=TIME(I)

		CALL EMISSI

	CC(I)=SS
	IF (INFO.GT.0)	PRINT 5,I,T,SS
 5	FORMAT(I8,F15.1,G16.3)
	CCSUM=CCSUM+SS
* Abbrechen bei Zeitvorgabe der Immissionssttzstellen ber Anfangszeit
* und Zeitschritt, wenn Konzentration auf Null abgefallen
	IF (JST.EQ.1)	THEN
		IF (CCSUM.GT.0. .AND. SS.LT.CCSUM*10.E-3)	THEN
* Anzahl gltiger Sttzstellen
			NNN=I
			NTM=I
			GOTO 510
			END IF
		END IF
500	CONTINUE

510	RETURN
	END

	SUBROUTINE	EMISSI
*-----------------------------------------------------------------------
* Unterprogramm zur Steuerung der zeitlichen Auflsung der Emission.
* Dazu wird die Anzahl der einzelnen Puffs solange erhht, bis
* verschiedene Abbruchkriterien erreicht sind.
*-----------------------------------------------------------------------
* I*4  I	Laufindex
* I*4  IT	Laufindex ber Anzahl der Emissionsabschnitte
*
* === aufgerufene Unterprogramme ===
* EMZEIT
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO


*----------------------------------------------------------------------
	DO 100 IT=1,NQ
	SU(IT)=-9E9
	S(IT)=0.
100	CONTINUE
* mit einem Puff rechnen
	N4=0
	CALL	EMZEIT
	GOTO 300

* umspeichern S(alt)=S(neu)
200	DO 220 IT=1,NQ
220	SU(IT)=S(IT)

* Anzahl der Puffs mit jedem Schritt um den Faktor 3 erhhen
300	N4=N4+1
	CALL	EMZEIT

	DO 400 IT=1,NQ
	IF (S(IT).NE.0. .OR. Z1Z(IT).NE.0.)	GOTO 500
400	CONTINUE
	GOTO 900

* Prfen ob Genauigkeit ausreicht
500	DO 600 IT=1,NQ
* wenn Z1Z=0 dann ist dieser Emissionsabschnitt hinreichend aufgelst
	IF (Z1Z(IT).EQ.0.)			GOTO 600
* (andere Abfrage als in S_FALL V.04 bzw. SF.FOR)
* grte Auflsung erreicht oder Genauigkeit besser 0.5%
* weitere Aufteilung, wenn
* - Konzentration noch Null und weniger als 3^9 Puffs
*   dann weiter auflsen
	IF (S(IT).EQ.0. .AND. N4.LT.9)		GOTO 200
* - maximale Aufteilung noch nicht erreicht und Genauigkeit der
*   Konzentrationsberechnung >0.5%
	IF (Z1Z(IT) .GT. AMAX1(XA/30.,.3) .AND.
     1	    ABS(S(IT)-SU(IT)) .GT. 0.005*S(IT))	GOTO 200
*exa-- wenn Genauigkeit nicht ausreicht, dann obige IF-Abfrage gegen
*exa   diese beiden Zeilen tauschen
Cexa	IF (ABS(S(IT)-SU(IT)) .GT. 0.005*S(IT))	GOTO 200
Cexa	Z1Z(IT)=0.
*exa--
600	CONTINUE

900	RETURN
	END

	SUBROUTINE	EMZEIT
*-----------------------------------------------------------------------
* Integration der Konzentration zahlreicher Einzelpuffs am Aufpunkt
* zur Zeit T.
*-----------------------------------------------------------------------
* R*4  A5	Hilfsvariable zur Konzentrationsberechnung
* R*4  A6	Hilfsvariable  "		"
* R*4  ALNHZ0	Hilfsgre (ln(H/Z0))
* R*4  C	Konzentrationsnderung durch Inversionseinflu
* R*4  DD	Hilfsvariable fr Reflektion an Inversion
* R*4  E10	Teilergebnisse bei der Konzentrationsberechnung
* R*4  E11	(Nummer entspricht zum Teil der Gleichungsnummer in
* R*4  E12	der Richtlinie)
* R*4  E13	...
* R*4  E2	...
* R*4  E20	...
* R*4  E21	...
* R*4  E3	...
* R*4  E4	...
* R*4  E5	...
* R*4  E6	...
* R*4  E7	...
* R*4  EE2	...
* R*4  FG	Faktoren und Exponenten zur Streuungsberechnung
* R*4  FK	...
* R*4  GG	...
* R*4  GK	...
* R*4  HMZA	Hilfsvariable (H-ZA)
* R*4  HPZA	Hilfsvariable (H+ZA)
* I*4  IP	Laufindex (Zeit innerhalb eines	Emissionsintervalls)
* I*4  IP1	Laufindexsteuerung (zeitlich Voran- oder
* I*4  IP2	Zurckschreiten je nach Lage des Puffs bezglich des
* I*4  IP3	Aufpunkts)
* I*4  IT	Laufindex ber die Emissionsintervalle (1...NQ)
* I*4  J	Anzahl der Reflektionen bei Bercksichtigung einer Inversion
* I*4  NB	Anzahl der Zeitabschnitte in einem Emissionsintervall (3**N4)
* I*4  NU	auf ganze m/s gerundete Windgeschwindigkeit
* R*4  S8	Hilfsvariable bei Konzentrationsberechnung
* R*4  SZ	Streuung in der Vertikalen (Sigma z)
* R*4  TQITM	Hilfsgre (Beginn des bearbeiteten Emissionsabschnitts)
* R*4  TV	Hilfsvariable bei der bestimmung der Gre TU
* R*4  TX	zeitliche Auflsung der Emissionsintervalle
*
* === Felder ===
* R*4  FGI(10)	Faktoren zur Berechnung der Streuungen in Abhngigkeit
* R*4  FGL(10)	von Windgeschwindigkeit und Bodenrauhigkeit.
* R*4  FGS(10,5)
* R*4  FKI(10)
* R*4  FKL(10)
* R*4  FKS(10,5)
* R*4  GGI(10)
* R*4  GGL(10)
* R*4  GGS(10,5)
* R*4  GKI(10)
* R*4  GKL(10)
* R*4  GKS(10,5)
*
* === aufgerufene Unterprogramme ===
* CUP
* DHUU
* ERF (R*4)
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX

	COMMON /CONST/	Z0I(5),PI,W2PI,DW2PI,DW2PI3,WPIH,W2

*--- Daten aus KONZ ---
	DIMENSION FGS(10,5),FKS(10,5),GGS(10,5),GKS(10,5)
	DIMENSION FGI(10),FKI(10),GGI(10),GKI(10)
	DIMENSION FGL(10),FKL(10),GGL(10),GKL(10)

	DATA FGS/
     1 8.721,8.843,9.101,9.360,9.670,10.08,10.67,11.54,12.84,14.77,
     2 8.788,8.987,9.214,9.483,9.821,10.27,10.88,11.75,13.01,14.85,
     3 9.010,9.153,9.370,9.661,10.05,10.55,11.20,12.08,13.29,14.97,
     4 9.153,9.283,9.502,9.817,10.25,10.80,11.50,12.40,13.57,15.10,
     5 9.302,9.428,9.656,10.00,10.49,11.11,11.88,12.81,13.93,15.26/

	DATA FKS/
     1 0.756,0.763,0.776,0.788,0.801,0.816,0.836,0.860,0.889,0.922,
     2 0.760,0.770,0.781,0.793,0.807,0.823,0.842,0.865,0.892,0.923,
     3 0.772,0.778,0.788,0.801,0.815,0.832,0.851,0.873,0.898,0.925,
     4 0.778,0.784,0.794,0.807,0.822,0.840,0.859,0.880,0.903,0.927,
     5 0.785,0.791,0.800,0.814,0.830,0.849,0.868,0.889,0.909,0.929/

	DATA GGS/
     1 0.932,0.870,0.754,0.657,0.560,0.457,0.346,0.237,0.142,0.073,
     2 0.897,0.803,0.710,0.616,0.518,0.418,0.315,0.217,0.133,0.071,
     3 0.793,0.733,0.653,0.562,0.464,0.366,0.278,0.190,0.120,0.068,
     4 0.734,0.684,0.610,0.519,0.422,0.326,0.240,0.167,0.109,0.065,
     5 0.677,0.634,0.563,0.474,0.376,0.284,0.206,0.143,0.096,0.062/

	DATA GKS/
     1 0.571,0.601,0.660,0.714,0.773,0.844,0.933,1.043,1.174,1.323,
     2 0.587,0.634,0.684,0.738,0.800,0.873,0.961,1.066,1.189,1.328,
     3 0.640,0.671,0.716,0.772,0.838,0.915,1.002,1.102,1.213,1.336,
     4 0.671,0.698,0.742,0.800,0.870,0.951,1.038,1.134,1.236,1.344,
     5 0.702,0.728,0.771,0.832,0.907,0.991,1.080,1.172,1.263,1.354/

	DATA FGI/
     1 10.28,10.37,10.53,10.76,11.10,11.56,12.19,13.05,14.24,15.90/
	DATA FKI/
     1 0.823,0.827,0.832,0.839,0.849,0.861,0.876,0.893,0.914,0.937/
	DATA GGI/
     1 0.415,0.397,0.369,0.331,0.286,0.235,0.182,0.131,0.087,0.051/
	DATA GKI/
     1 0.876,0.890,0.913,0.946,0.990,1.045,1.113,1.193,1.286,1.392/
	DATA FGL/
     1 11.49,11.58,11.75,12.00,12.35,12.83,13.49,14.38,15.60,17.29/
	DATA FKL/
     1 0.859,0.861,0.865,0.871,0.879,0.889,0.901,0.916,0.933,0.953/
	DATA GGL/
     1 0.242,0.232,0.217,0.196,0.171,0.142,0.112,0.083,0.056,0.034/
	DATA GKL/
     1 1.037,1.048,1.066,1.093,1.129,1.174,1.229,1.296,1.375,1.466/
*-------
* Bei mittl. Ausbreitungssituation Geschwindigkeiten bis 15m/s mglich
	NU=MIN0(NINT(U),10)
	GOTO (1130,1140,1150),IK

1130	FG=FGS(NU,IZ0)
	FK=FKS(NU,IZ0)
	GG=GGS(NU,IZ0)
	GK=GKS(NU,IZ0)
	GOTO 1160

1140	FG=FGI(NU)
	FK=FKI(NU)
	GG=GGI(NU)
	GK=GKI(NU)
	GOTO 1160

1150	FG=FGL(NU)
	FK=FKL(NU)
	GG=GGL(NU)
	GK=GKL(NU)

1160	ALNHZ0=ALOG(H/Z0)	! hhenabhngige Sigmas
!1160	ALNHZ0=ALOG(20./Z0)	! feste Sigmas
*-------
* Anzahl der Puffs in NB
	NB=3**N4
	DH=0.
	SS=0.

* Hilfsgre TQITM (Startzeit des ersten Abschnitts)
	TQITM=0.
* Schleife ber die Emissionsabschnitte
	DO  800  IT=1,NQ
	UM=U
* Hilfsgre TQITM (Startzeit dieses Abschnitts)
	IF (IT.GT.1)	TQITM=TQ(IT-1)

	IF (NB.GT.1 .AND. Z1Z(IT).EQ.0.)	GOTO 700
	IF (T-TQITM .LT. 0.)			GOTO 700
C	Z1Z(IT)=1.
	S(IT)=S(IT)/3.
* zeitl. Auflsung der Puffs fr jedes Emissionsintervall
	TX=TD(IT)/NB

	IF (INFO.GT.1 .AND. N4.GT.1)	CALL CUP (N4+IT)

* Schwerpunkt vor oder hinter Aufpunkt
	IF ((T-TQ(IT))*U.GT.XA)	THEN
		IP1=NB*2-1
		IP2=1
		IP3=-2
		ELSE
		IP1=1
		IP2=NB*2-1
		IP3=2
		END IF
* Schleife ber die Puffs
	DO  600  IP=IP1,IP2,IP3
* dieser Puff wurde im vorherigen Schritt bereits bearbeitet
	IF (MOD(IP,3).EQ.0)	GOTO 600

* ab und zu ein Pnktchen auf den Schirm, sofern gewnscht
	IF (INFO.GT.1)	THEN
	  IF (MOD(IP,11).EQ.0)	CALL CUP (N4+IT)
	  END IF

* Reisezeit eines Puffs
	TA=T-TQITM-FLOAT(IP)*TX/2.
	IF (TA.LE.0.)		GOTO 700

	IF (NUE.EQ.1)	THEN
* Bei berhhung ist die effektive Quellhhe vom Abstand des
* Puffs von der Quelle abhngig. Dieser Abstand (TU) wird iterativ
* bestimmt, da die Transportgeschwindigkeit mit zunehmender Quellhhe
* ansteigt.
* Da Inversionshhe bei der Berechnung der Aufpunkte nach oben wandert,
* vor jeder neuen Rechnung auf die Mindesthhe HI0 setzen.
		HI=HI0
		TU=TA*U
300		CALL DHUU (1,IT)
* neue Transportgeschwindigkeit
		TV=TA*UU
* wenn Differenz kleiner als 10% dann Iteration abbrechen
		IF (ABS(TV-TU)/TV .LT. 0.1)	GOTO 400
		TU=TV
		GOTO 300
* Hhe der Inversion bei ungnstiger Ausbreitungssituation (IU>0)
400		IF (INVRS .AND. HI.LT.H)	HI=H
		ALNHZ0=ALOG(H/Z0)
		END IF

	TU=TA*UU
	IF (UM.LT.UU)	UM=UU

*-----------------------------------------------------------------------
* (hier steht das ehemalige Unterprogramm KONZ)
*-----------------------------------------------------------------------
* Berechnung der Konzentration fr einen Einzelpuff
* Die Abfragen nach <9.35 sind dazu da, UNDERFLOW's abzufangen;
* ebenso die ALOG10-Abfrage vor der Berechnung von S(IT)
*-----------------------------------------------------------------------

	IF (TU.LT.100.)		THEN
		SY=0.07*(FG -ALNHZ0)   *100.**FK
		SZ=0.13*(8.7-ALNHZ0)*GG*100.**GK
		IF (SY.LT.1.)	SY=1.
		IF (SZ.LT.1.)	SZ=1.
		SY=(SY-DW2PI)*TU/100.+DW2PI
		SZ=(SZ-DW2PI)*TU/100.+DW2PI
	ELSE
		SY=0.07*(FG -ALNHZ0)   *TU**FK
		SZ=0.13*(8.7-ALNHZ0)*GG*TU**GK
* bei eff. Quellhhen ber 120m knnen Streuungen negativ sein
* deshalb Abfrage danach
		IF (SY.LT.1.)	SY=1.
		IF (SZ.LT.1.)	SZ=1.
	END IF

	A5=W2*SZ
	A6=W2*SY
	EE2=(XA-TU)/A6
	IF (ABS(EE2).LE.9.35)	THEN
		E2=EXP(-(EE2**2))
		ELSE
		E2=0.
		END IF
* wenn Quellausdehnung in x-Richtung (E5)
	IF (LXQ)	THEN
		E5=WPIH*SY*(ERF(EE2+XQ/A6)-ERF(EE2))
		IF (E2.LT.E5)	E2=E5
		END IF
	IF (E2.EQ.0.)	GOTO 500

* Aufpunkt YA<>0 bercksichtigen
	IF (YA.NE.0.)	THEN
		E20=0.
* wenn Quellausdehnung in y-Richtung
		IF (LYQ) E20=
     1		   WPIH*SY*(ERF((YA+YQ/2.)/A6)-ERF((YA-YQ/2.)/A6))
		E21=YA/A6
		IF (ABS(E21).LE.9.35)	THEN
			E21=EXP(-(E21**2))
			ELSE
			E21=0.
			END IF
		IF (E21.LT.E20)	E21=E20
		E2=E2*E21
		IF (E2.EQ.0.)	GOTO 500

		ELSE
* Standardfall (YA=0)
* wenn Quellausdehnung in y-Richtung
		IF (LYQ) THEN
			E2=E2*W2PI*SY*ERF(YQ/(2.*A6))
			IF (E2.EQ.0.)	GOTO 500
			END IF
		END IF

* vertikal
	HMZA=H-ZA
	HPZA=H+ZA
	E10=HMZA/A5
	E11=HPZA/A5

	E3=0.
	IF (E10.LE.9.35)	E3=   EXP(-(E10**2))
	IF (E11.LE.9.35)	E3=E3+EXP(-(E11**2))
* wenn Quellausdehnung in z-Richtung (E6)
	IF (LZQ)	THEN
		E6=WPIH*SZ*
     1		   (ERF(E10)-ERF(E10-ZQ/A5)+
     2		    ERF(E11)-ERF(E11-ZQ/A5))
		IF (E3.LT.E6)	E3=E6
		END IF

* keine Inversion bei mittlerer Ausbreitungssituation (IU=0)
	IF (INVRS)	THEN
* bei ungnstigen Ausbreitungssituationen reflekiert Inversion
		C=0.
		J=0

* virtuelle Quelle in der Hhe DD
1200		J=J+1
		DD=(2*J)*HI
		E10=(DD+HMZA)/A5
		E11=(DD+HPZA)/A5
		E12=(DD-HPZA)/A5
		E13=(DD-HMZA)/A5

		E4=0.
		IF (E10.LE.9.35)	E4=   EXP(-(E10**2))
		IF (E11.LE.9.35)	E4=E4+EXP(-(E11**2))
		IF (E12.LE.9.35)	E4=E4+EXP(-(E12**2))
		IF (E13.LE.9.35)	E4=E4+EXP(-(E13**2))
* wenn Quellausdehnung in z-Richtung (E7)
		IF (LZQ)	THEN
			E7=WPIH*SZ*(
     1			   -ERF(E12)+ERF(E12+ZQ/A5)
     2			   -ERF(E13)+ERF(E13+ZQ/A5)
     3			   +ERF(E10)-ERF(E10-ZQ/A5)
     4			   +ERF(E11)-ERF(E11-ZQ/A5) )
			IF (E4.LT.E7)	E4=E7
			END IF
* wenn Beitrag der Reflexion zu gering, dann abbrechen
		IF (E4.LT.1.E-30)		GOTO 1300
		C=C+E4
* solange Beitrag grer als 5% ist weitermachen
		IF (E4.GE.0.05*(C+E3))		GOTO 1200

1300		E3=E3+C
		END IF
	IF (E3.EQ.0.)		GOTO 500

	S8=DW2PI3/(SY**2*SZ)
	IF (E2.EQ.0.)	GOTO 500					!V2.12
c	IF (S8.EQ.0.)	GOTO 500					!V2.12
	IF (ALOG10(E2)+ALOG10(E3)+ALOG10(S8).GT.-30.)	THEN
*- KONZ-Ende -----------------------------------------------------------
		S(IT)=S(IT)+E2*E3*S8*TX
		GOTO 600
		END IF

* SSS ist hier Null
500	IF ((T-TQ(IT))*UU.GE.XA)	GOTO 700
	IF ((T-TQITM) *UU.LE.XA)	GOTO 700

600	CONTINUE
* ber die Emissionsintervalle aufsummieren
* /g/ der Quellstrkeangabe in /mg/ umrechnen (Faktor 1000.)
700	SS=SS+S(IT)*Q(IT)*1000.

* wenn Z1Z kleiner als 1/100 der Aufpunktsentfernung, dann max.
* Auflsung erreicht
	Z1Z(IT)=TX*UM/3.
	IF (Z1Z(IT).LE.AMAX1(.3,XA/100.))	Z1Z(IT)=0.

800	CONTINUE

	RETURN
	END

	FUNCTION	ERF (X)
*-----------------------------------------------------------------
* ERROR-Function
* Sollte das Stoerfallprogramm auf einem Grorechner implementiert
* werden, so ist es empfehlenswert diese FUNCTION durch die in den
* meisten Systembibliotheken vorhandene ERROR-Function zu ersetzen.
* Diese sind meist schneller und genauer als diese Nherungsfunk-
* tion.
*-----------------------------------------------------------------
* R*4  A	Betrag des Arguments der Errorfunction
* R*4  X	Argument der Errorfunction
*-----------------------------------------------------------------
	ERF=0.
	A=ABS(X)
	IF (A.LT.2.E-6)		RETURN
	IF (A.LE.4.)		GOTO 10
	ERF=SIGN(1.,X)
	RETURN

 10	ERF=1.-1./(1.+.705230784E-1*A+.422820123E-1*A**2+
     1	.92705272E-2*A**3+.1520143E-3*A**4+.2765672E-3*A**5+
     1	.430638E-4*A**6)**16
	ERF=SIGN(ERF,X)
	RETURN
	END

	SUBROUTINE	DHUU (IPR,IT)
*-----------------------------------------------------------------------
* Berechnung der berhhung und der ber die effektive Quellhhe
* gemittelten Windgeschwindigkeit.
*-----------------------------------------------------------------------
* R*4  DG	Obergrenze fr die berhhung
* R*4  DGI	Obergrenze der berhhung bei indifferenter Temperatur-
* 		schichtung
* R*4  DHI	berhhung bei labiler Temperaturschichtung
* R*4  H0	Quellhhe bzw. Hhe des Schwerpunktes einer nicht punkt-
* 		frmigen Quelle
* I*4  IPR	1= Berechnung von berhhung und Windgeschwindigkeit UU
* 		3= nur Windgeschwindigkeit UU berechnen
* I*4  IT	Kennung des Emissionsabschnitts
* R*4  UH0	Windgeschwindigkeit in der Hhe H0
*
* === Felder ===
* R*4  AM(3)	Exponenten fr Potenzprofilansatz des Windprofils
*
* === aufgerufene Unterprogramme ===
* - keine -
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /EMVER/	NQ,TQ(nemi),Q(nemi),QH(nemi),R(nemi),RO(nemi),
     1			TT(nemi),TD(nemi),S(nemi),Z1Z(nemi),SU(nemi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

* Exponenten des Potenzprofils fr 3 Temperaturschichtungen
	DIMENSION AM(3)
	DATA AM/.37,.28,.2/

	H=HQ
	IF (IPR.EQ.3)	GOTO 4

*----------------------------------------------------------------------
* Berechung der berhhung
*----------------------------------------------------------------------
	H0=HQ-ZQ/2.
	IF (H0.LT. 10.)	H0= 10.
	IF (H0.GT.200.)	H0=200.
* Geschwindigkeit in der Hhe H0 aus Potenzprofil bestimmen
	UH0=U*(H0/10.)**AM(IK)

	GOTO (7,8,9),IK

*----------------------------------------------------------------------
* Stabil
* (die berhhung bei stabiler Schichtung darf hchstens gleich der
* berhhung bei indifferenter Schichtung sein)
*----------------------------------------------------------------------
  7	DH =3.34*QH(IT)**0.333*TU**0.667/UH0
	DG =74.4*QH(IT)**0.333/UH0**0.333
	IF (DH.GT.DG)	DH=DG
* indiff.
	DHI=2.84*QH(IT)**0.333*TU**0.667/UH0
	DGI=102.*QH(IT)**0.6/UH0
	IF (DHI.GT.DGI)	DHI=DGI
	IF (DH.GT.DHI)	DH=DHI
	H=HQ+DH
	GOTO 4

*----------------------------------------------------------------------
* Indifferent
*----------------------------------------------------------------------
  8	DH=2.84*QH(IT)**0.333*TU**0.667/UH0
	DG=102.*QH(IT)**0.6/UH0
	IF (DH.GT.DG)	DH=DG
	H=HQ+DH
	IF (H.GT.800.)	H=800.
	GOTO 4

*----------------------------------------------------------------------
* Labil
*----------------------------------------------------------------------
  9	DH=3.34*QH(IT)**0.333*TU**0.667/UH0
	DG=146.*QH(IT)**0.6/UH0
	IF (DH.GT.DG)	DH=DG
	H=HQ+DH
	IF (H.GT.1100.)	H=1100.

*----------------------------------------------------------------------
* Berechnung der ber die effektive Quellhhe gemittelten
* Windgeschwindigkeit
*----------------------------------------------------------------------
  4	H0=H
	IF (H0.LT. 10.)	H0= 10.
	IF (H0.GT.200.)	H0=200.
	UU=U/(AM(IK)+1.)*(H0/10.)**AM(IK)

	RETURN
	END

	SUBROUTINE	MAXKON (Cmax,Tmax)
*----------------------------------------------------------------------
* Maximalkonzentration bestimmen:
* Aus dem zunchst berechneten Konzentrationsverlauf wird die vor-
* lufige Maximalkonzentration und Eintrittszeit bestimmt. Dann wird
* durch weitere Schachtelung um diese Eintrittszeit das genaue Maximum
* bestimmt.
*----------------------------------------------------------------------
* R*4  CM	Maximalkonzentration nach der Unterteilung
* R*4  CMAX	maximale Konzentration aus dem Konzentrationsverlauf
* R*4  DTM	Zeitschritt
* R*4  T1	Anfangszeit ab der das Maximum gesucht wird
* R*4  T2	Endzeit bis zu der das Maximum gesucht wird
* R*4  TMAX	Zeitpunkt zu dem die max. Konzentration beobachtet wird
* I*4  I	Laufindex
* I*4  I1	eine Sttzstelle vor CMAX
* I*4  I2	einen Sttzstelle hinter CMAX
* I*4  IMAX	Nr. der Sttzstelle an der CMAX beobachtet wird
*
* === Felder ===
* R*4  CMALT(3)	Maximalkonzentration fr jede Ausbreitungsklasse fr die
*		vorangegangene Geschwindigkeitsstufe
* L*4  Z9C(3)	Flag fr jede Ausbreitungsklasse ob Geschwindigkeit weiter
*		erhht werden soll
*
* === aufgerufene Unterprogramme ===
* EMISSI
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX

	LOGICAL		Z9C(3)
	REAL		CMALT(3)

*----------------------------------------------------------------------
* Maximum aus dem Konzentrationsverlauf bestimmen
*----------------------------------------------------------------------
	CMAX=0.
	DO 100 I=1,NNN
	IF (CMAX.LT.CC(I))	THEN
		CMAX=CC(I)
		IMAX=I
		END IF
100	CONTINUE
	IF (CMAX.EQ.0.)		GOTO 550
	TMAX=TIME(IMAX)

* den Bereich um die Maximalkonzentration nher untersuchen, indem
* eine Unterteilung in 5 weitere Zeitschritte erfolgt

	I1=MAX0(  1,IMAX-1)
	I2=MIN0(NNN,IMAX+1)
	T1=TIME(I1)+1.
	T2=TIME(I2)
	IF (T1.GE.T2)		GOTO 550

	CM=CMAX
* Mindestschrittweite 1sec
150	DTM=AMAX1(1.,AINT((T2-T1)/5.))
	IF (INFO.GT.0)	PRINT 1,T1,T2
 1	FORMAT(' Maximalkonz. wird zwischen',F7.1,' und',F7.1,
     1	' s erreicht')
	T=T1

200	CALL EMISSI
	IF (INFO.GT.0)	PRINT 2,T,SS
 2	FORMAT(13X,F10.1,G16.3)
	IF (SS.GE.CM)	THEN
		CM=SS
		TMAX=T
		END IF
	T=T+DTM
	IF (T.LT.T2)	GOTO 200
* Abbruch, wenn Genauigkeit kleiner 1%
	IF (ABS(CM-CMAX)/CM.LT.0.01)	GOTO 500
	CMAX=CM
	T1=TMAX-DTM+1.
	T2=TMAX+DTM
* weiter wenn Zeitschritt noch >1sec
	IF (DTM.GT.1.)	GOTO 150

500	CMAX=CM

* wenn nur spezielle Ausbreitungssituation untersucht wird, dann kein
* Maximum aller Stabilitten ermitteln
550	IF (MW.NE.0)		RETURN

* Initialisieren (bei mittlerer Ausbreitungssituation)
	IF (IU.EQ.0)		THEN
		DO 600 I=1,3
		Z9C(I)=.FALSE.
600		CMALT(I)=0.
		CCMAX=0.
		CINC=.TRUE.
		RETURN
		END IF

* Maximalkonzentration der ungnstigsten Ausbreitungssituation ermitteln
* die Gren -  Zeit, Ausbreitungsklasse und Geschwindigkeit merken
	IF (CMAX.GT.CCMAX)	THEN
		CCMAX=CMAX
		TCMAX=TMAX
		KCMAX=IK
		UCMAX=UUXA
		ICMAX=IU
		HCMAX=HIXA
		END IF

* wenn Konzentrationen bei Steigerung der Geschwindigkeit um mehr als
* 10% abnehmen, dann Endeflag setzen
	IF (CMAX.LT.1.1*CMALT(IK))	Z9C(IK)=.TRUE.
	CMALT(IK)=CMAX
	CINC=.NOT.(Z9C(1).AND.Z9C(2).AND.Z9C(3))

	RETURN
	END

	SUBROUTINE	DOSIS
*----------------------------------------------------------------------
* Dosis aus dem Konzentrationsverlauf bestimmen:
* Integration ber die Zeit. Diese ist um so genauer, je linearer der
* Konzentrationsverlauf zwischen 2 Sttzstellen in Wirklichkeit ist.
* Deshalb Anzahl der Immissionssttzstellen nicht zu gering whlen.
*----------------------------------------------------------------------
* R*4  CD	Dosis
* I*4  I	Laufindex
*
* === Felder ===
* R*4  CDALT(3)	Dosis jeder Ausbreitungsklasse bei der vorangegangenen
*		Geschwindigkeitsstufe
* L*4  Z9D(3)	Flag fr jede Ausbreitungsklasse ob Geschwindigkeit weiter
*		erhht werden soll
*
* === aufgerufene Unterprogramme ===
* EMISSI
*-----------------------------------------------------------------------
	PARAMETER (nemi=20)
	PARAMETER (nimi=100)

	COMMON /IMVER/	CC(nimi),TIME(nimi),TS(nimi)

	LOGICAL		INVRS,LXQ,LYQ,LZQ
	COMMON		IGAS,H,HI,DH,IU,TA,U,UU,UM0,
     1			SS,T,IK,TTD,N4,Z0,TU,NNN,
     2			SY,CCSUM,
     3			INVRS,LXQ,LYQ,LZQ

	COMMON /INPUT/	UM,HM,HQ,XQ,YQ,ZQ,XA,YA,ZA,
     1			T0,DT,
     1			IAI,IZ0,NUE,NTM,NZI,MW,IW,IQ,IQA,JO,JST,INFO

	LOGICAL		DINC,CINC,Z9(3)
	COMMON /DMKM/	HI0,HIXA,UUXA,HXA,Z9,
     1			CDMAX,UDMAX,HDMAX,KDMAX,IDMAX,DINC,
     1			CCMAX,UCMAX,HCMAX,KCMAX,ICMAX,CINC,TCMAX

	LOGICAL		Z9D(3)
	REAL		CDALT(3)

*----------------------------------------------------------------------
*----------------------------------------------------------------------
	CD=0.
	IF (CCSUM.EQ.0.)	GOTO 250
	IF (TTD.GT.0.)	THEN
* quidistante Abstnde der Immissionssttzstellen
* CCSUM enthlt bereits die Summe der Konzentrationen, mu also nur noch
* mit dem Zeitschritt multipliziert werden.
		CD=CCSUM*TTD
		ELSE
* bei nicht quidistanten Abstnden
		CD=CC(1)*(TIME(2)-TIME(1))
		DO 200 I=2,NNN-1
200		CD=CD+CC(I)*(TIME(I+1)-TIME(I-1))*0.5
		CD=CD+CC(NNN)*(TIME(NNN)-TIME(NNN-1))
		END IF

	PRINT 1,CD
	IF (IAI.EQ.1 .AND. (IU.EQ.0 .OR. NZI.EQ.0)) WRITE(33,1) CD
  1	FORMAT(/' Dosis',T26,G15.4,' mg*s/m**3')

* wenn nur spezielle Ausbreitungssituation untersucht wird, dann kein
* Maximum aller Stabilitten ermitteln
250	IF (MW.NE.0)		RETURN
* Initialisieren (bei mittlerer Ausbreitungssituation)
	IF (IU.EQ.0)		THEN
		DO 300 I=1,3
		CDALT(I)=0.
300		Z9D(I)=.FALSE.
		CDMAX=0.
		DINC=.TRUE.
		RETURN
		END IF
* Maximum bestimmen und Ausbreitungssituation festhalten
	IF (CD.GT.CDMAX)	THEN
		CDMAX=CD
		KDMAX=IK
		UDMAX=UUXA
		HDMAX=HIXA
		IDMAX=IU
		END IF
* wenn Konzentrationen bei Steigerung der Geschwindigkeit um mehr als
* 10% abnehmen, dann Endeflag setzen
	IF (CD.LT.1.1*CDALT(IK))	Z9D(IK)=.TRUE.
	CDALT(IK)=CD
	DINC=.NOT.(Z9D(1).AND.Z9D(2).AND.Z9D(3))

	RETURN
	END

	SUBROUTINE	GETJN (IN,*)
*----------------------------------------------------------------------
* Antwort auf Entscheidungsfrage einlesen:
* kann sein:	'N' oder 'n' fr NEIN
*		beliebiges Zeichen fr JA
*		RETURN wenn Vorgabe bernommen werden soll
*----------------------------------------------------------------------
* I*4  IN	In=1 - Ja, In=2- Nein
* CHAR JN	'J' fr JA und 'N' fr NEIN
*----------------------------------------------------------------------
	CHARACTER JN*1

	READ (*,'(A)',END=200) JN
* wenn RETURN dann JN=' '
	IF (JN.NE.' ')	THEN
		IF (JN.EQ.'N' .OR. JN.EQ.'n') THEN
			IN=2
			ELSE
			IN=1
			END IF
		END IF
	RETURN
* nach CTRL_Z Rckkehr zur alternativen Adresse
200	RETURN 1
	END

	SUBROUTINE	PARS2 (AA,AB,*)
*-----------------------------------------------------------------------
* 2 Zahlen, die durch ein Komma getrennt sind aus dem String extrahieren.
*-----------------------------------------------------------------------
* I*4  I	Hilfsgre (Position des Komma zwischen 2 Zahlen)
* I*4  L	Lnge der Eingabe
* R*4  AA	erste Zahl (aus String konvertiert)
* R*4  AB	zweite Zahl
*-----------------------------------------------------------------------
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING


100	READ (*,'(A)',END=111)	STRING
	L=NBLANK (STRING)
	IF (L.GT.0)	then
		I=INDEX(STRING(1:L),',')
		IF (I.GT.1)
     1		 READ (STRING,1,ERR=222) AA
		IF (I.GE.1 .AND. I.LT.L)
     1		 READ (STRING(I+1:L),1,ERR=222) AB
		end if
	RETURN
111	RETURN 1
222	PRINT 2
	GOTO 100

 1	FORMAT(BN,G10.0)
 2	FORMAT(' !! falsche Eingabe !!'/T50,'>>'\)
	END

	SUBROUTINE	GET1R (RN,RB1,RB2,*)
*----------------------------------------------------------------------
* Eine REAL-Zahl einlesen und prfen ob sie in den vorgegebenen
* Grenzen (RB1,RB2) liegt. Bei RETURN wird die Vorgabe bernommen.
*----------------------------------------------------------------------
* R*4  AA	Hilfsgre Real
* I*4  IA	Hilfsgre Integer
* I*4  IB1,IB2	Wertebereich Integer
* I*4  IN	bergabewert Integer
* R*4  RB1,RB2	Wertebereich Real
* R*4  RN	bergabewert Real
*----------------------------------------------------------------------
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	CHARACTER	QUEART(4)*8,QUEDIM(4)*8,
     1			STNAME(maxgas)*24,
     2			GEBIET(maxgeb)*32,
     3			FORM(4)*64,
     4			DATEI*30,JANEIN(2)*4,
     5			TITEL*70,STRING*80

	COMMON /TEXT/	QUEART,QUEDIM,STNAME,GEBIET,FORM,
     1			DATEI,JANEIN,TITEL,STRING


100	READ (*,'(A)',END=200,ERR=300) STRING
	L=NBLANK(STRING)
	IF (L.GT.0)	THEN
		READ (STRING,1,ERR=300) AA
* < Untergrenze prfen
		IF (AA.LT.RB1)	THEN
			PRINT 40,'>',RB1
			GOTO 100
			END IF
* > Obergrenze prfen (sofern RB2>0)
		IF (RB2.GT.0.)	THEN
			IF (AA.GT.RB2)	THEN
				PRINT 40,'<',RB2
				GOTO 100
				END IF
			END IF
		RN=AA
		END IF
	RETURN

* bei Eingabefehler
300	PRINT 10
	GOTO 100

*----------------------------------------------------------------------
	ENTRY	GET1I (IN,IB1,IB2,*)
*----------------------------------------------------------------------
* Eine INTEGER-Zahl einlesen und prfen ob sie in den vorgegebenen
* Grenzen (IB1,IB2) liegt. Bei RETURN wird die Vorgabe bernommen.
*----------------------------------------------------------------------

400	READ (*,'(A)',END=200,ERR=500) STRING
	L=NBLANK(STRING)
	IF (L.GT.0)	THEN
		READ (STRING,1,ERR=500) AA
		IA=NINT(AA)
		IF (IA.LT.IB1 .OR. IA.GT.IB2)	THEN
			PRINT 20,IB1,IB2
			GOTO 400
			ELSE
			IN=IA
			END IF
		END IF
	RETURN

* nach CTRL_Z Rckkehr zur alternativen Adresse
200	RETURN 1

* bei Eingabefehler (z.B. Text statt Zahl)
500	PRINT 10
	GOTO 400

  1	FORMAT(BN,G10.0)
 10	FORMAT(' !! falsche Eingabe !!'/T70,'>'\)
 20	FORMAT(' !! nur Werte von',I4,' bis',I5,' mglich !!',T70,'>'\)
 40	FORMAT(' !! nur Werte ',A1,' oder =',F10.1,' zulssig !!',
     1		T70,'>'\)
	END

	SUBROUTINE	CLS
*-----------------------------------------------------------------------
* Bildschirm lschen
* auf PC: CLS = ESC [2J !! bei geladenem Treiber ANSI.SYS !!
*-----------------------------------------------------------------------
* Bei VT100-Bildschirmen an VAX-Rechnern
*VAX	PRINT 1, 27,27
*VAX 1	FORMAT(1H$,A1,'[H',A1,'[J')
*-------
	PRINT 1,27
!  1	FORMAT(1X\A1,'[2J')
  1	FORMAT(1H+,A1,'[2J')
	RETURN
	END

	SUBROUTINE	CUP (I)
*-----------------------------------------------------------------------
* Zahl ausgeben und Cursor 1 Zeile nach oben setzen.
* (auf PC: CUP = ESC [A !! bei geladenem Treiber ANSI.SYS !!)
*-----------------------------------------------------------------------
* I*4  I	bergebenes Argument (Ma fr Schachtelungstiefe)
* I*4  I0	I des vorhergegangenen Aufrufs
* I*4  K	interner Zhler zur Ausgabe von P
* CHAR P	Punkte
*-----------------------------------------------------------------------
	CHARACTER P*10
	DATA P/'..........'/
	DATA I0/0/

	IF (I.NE.I0)	THEN
		K=1
		ELSE
		K=K+1
		IF (K.GT.10)	K=1
		END IF
	PRINT 1,I+48,P(1:K),27
   1	FORMAT('..',A1,A,1X,A1,'[A')
	I0=I
	RETURN
	END

	SUBROUTINE	WAIT
*-----------------------------------------------------------------------
* Warten bis die RETURN-Taste bettigt wurde
*-----------------------------------------------------------------------
	PRINT 1,27,24,50
  1	FORMAT (1X,A1,'[',I2,';',I2,'H -- weiter mit <RETURN> --'\)
	READ (*,*)

	RETURN
	END

$IF DEFINED (MSOFT)
	FUNCTION	NBLANK (TEXT)
*-----------------------------------------------------------------------
* Berechnet die Lnge eines Strings indem, von hinten beginnend, das
* erste Zeichen, das kein Blank ist, gesucht wird.
*-----------------------------------------------------------------------
* I*4  L	Laufvariable
* CHAR TEXT	von diesem Text soll die Lnge bestimmt werden
*-----------------------------------------------------------------------
	CHARACTER TEXT*(*)

	DO  10  L=LEN(TEXT),1,-1
	IF (ICHAR(TEXT(L:L)).GT.ICHAR(' '))	GOTO 20
10	CONTINUE
20	NBLANK=L
	RETURN
	END
$ENDIF

	SUBROUTINE	SORT (TS,N)
*-----------------------------------------------------------------------
* Vektor aufsteigend sortieren.
* (Immissionssttzstellen knnen unsortiert eingegeben werden. Damit
* dann bei der Bestimmung der Dosis oder der Maximalkonzentration keine
* Fehler entstehen mu aufsteigend sortiert werden)
*-----------------------------------------------------------------------
* R*4  H	Zwischenspeicher
* I*4  I	Laufindex
* I*4  J	Laufindex
* I*4  N	Anzahl der Zahlen in TS
* === Felder ===
* R*4  TS(N)	vorgegebene Immissionssttzstellen
*-----------------------------------------------------------------------
	DIMENSION TS(N)

	DO  100  J=1,N-1
	DO  100  I=J+1,N
	IF (TS(I).LT.TS(J))	THEN
		H=TS(J)
		TS(J)=TS(I)
		TS(I)=H
		END IF
100	CONTINUE

	RETURN
	END

	SUBROUTINE FRAME (TEXT)
*-----------------------------------------------------------------------
* Seitenberschrift mit Doppelrahmen ausgeben
*-----------------------------------------------------------------------
*- auf anderen Rechnern, die nicht ber die hier verwendeten Grafik-
* symbole verfgen, sind andere darstellbare Zeichen zu verwenden.
*-----------------------------------------------------------------------
* I*4  I	Laufindex
* I*4  L	lokale Hilfsvariable
* I*4  L1	 ''
* I*4  L2	 ''
* CHAR TEXT	ist der auszugebende String
* === aufgerufene Unterprogramme ===
* CLS          
*-----------------------------------------------------------------------
	CHARACTER	TEXT*(*)

	CALL	CLS

	L=LEN(TEXT)
	L1=(77-L)/2
	L2=77-L1-L
	PRINT 1,(' ',I=1,L1),(TEXT(I:I),I=1,L),(' ',I=1,L2)
 1	FORMAT(
     1	' ',77(''), ''/
     2	' ',77A1,T80,''/
     3	' ',77(''), ''/)
	RETURN
	END

	SUBROUTINE UZDIS ()
*-----------------------------------------------------------------------
* Berechnung der unteren Znddistanzen
*-----------------------------------------------------------------------
* I*4 M		- Laufindex fr Mittelwert und Maximalwert
* R*4 DE	- Steigung der Kurve
* R*4 DX	- Offset
*-----------------------------------------------------------------------
	PARAMETER (maxgas=40)
	PARAMETER (maxgeb=25)

	COMMON /SGAS/	DXI(2,maxgeb),DXC(2,maxgeb),DTI(2,maxgeb),
     1			SIEDP(maxgas),RHONOR(maxgas),UZG(maxgas),
     2          	MGAS,MGEB,NGAS,NGEB,NFORM,TPROZ,
     3			QTOTAL,RLC(2),UZD(2),UC,CK,IFREI,IERR,NUR2,
     4			XK(2,2),DTS(2),XR(2),
     5			UZDAT(15,2,2,maxgeb),UCDAT(15,2,2,maxgeb)

*----------------------------------------------------------------------
* brennbares Gas? - Nein - keine untere Znddistanz
*----------------------------------------------------------------------
	IF (UZG(NGAS).LT.0.)	THEN
		UZD(1)=-1.
		UZD(2)=-1.
		RETURN
		END IF

*----------------------------------------------------------------------
* Mittelwert und Maximalwert
*----------------------------------------------------------------------
	DO  100  M=1,2

* Konzentrationsintervall suchen
	IN=1
 50	IN=IN+1
	IF (UZG(NGAS).LT.UCDAT(IN,M,IFREI,NGEB)) GOTO 50

* lineare Interpolation zwischen den beiden Znddistanzen
	DE=(UZDAT(IN,M,IFREI,NGEB)-UZDAT(IN-1,M,IFREI,NGEB))/
     1	   (UCDAT(IN,M,IFREI,NGEB)-UCDAT(IN-1,M,IFREI,NGEB))

	DX=(UZG(NGAS)-UCDAT(IN-1,M,IFREI,NGEB))*DE

	UZD(M)=(UZDAT(IN-1,M,IFREI,NGEB)+DX)*RLC(IFREI)

100	CONTINUE

	RETURN
	END
